package stella.vision;

import java.awt.Window;
import javax.swing.SwingUtilities;
import stella.gui.JSGuiTools;
import java.awt.event.KeyEvent;
import java.awt.event.KeyAdapter;
import java.awt.Desktop;
import stella.util.ByteBufferStream;
import java.nio.ByteBuffer;
import org.apache.commons.codec.binary.Base64;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.io.BufferedInputStream;
import stella.util.ByteUtil;
import java.io.RandomAccessFile;
import java.util.Date;
import java.util.UUID;
import java.nio.channels.FileLock;
import java.nio.channels.FileChannel;
import java.io.InputStream;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.FileNotFoundException;
import java.io.EOFException;
import java.io.DataInputStream;
import stella.util.JSCryptInputStream;
import java.io.FileInputStream;
import java.awt.event.ActionEvent;
import javax.swing.border.EmptyBorder;
import stella.gui.DM;
import stella.resource.Resource;
import javax.swing.border.EtchedBorder;
import javax.swing.ImageIcon;
import javax.swing.JPanel;
import java.awt.BorderLayout;
import stella.resource.VRes;
import java.text.SimpleDateFormat;
import javax.swing.JButton;
import javax.swing.JLabel;
import java.awt.event.ActionListener;
import stella.gui.JSDialog;
import java.util.Iterator;
import stella.util.JSStringUtil;
import java.util.ArrayList;
import javax.swing.JMenuItem;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import java.io.PrintStream;
import stella.util.CodeException;
import java.util.Random;
import java.io.DataOutputStream;
import stella.util.JSCryptOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.InetAddress;
import stella.util.ThreadEx;
import stella.vision.server.BridgeConnectionListener;
import stella.vision.server.Bridge;
import stella.JVWMICtrl;
import stella.util.DesktopUtil;
import stella.gui.JSMessageDialog;
import java.util.prefs.Preferences;
import stella.JVWMI;
import javax.swing.JOptionPane;
import java.util.TimerTask;
import stella.util.JSFileUtil;
import stella.resource.Message;
import stella.util.DT;
import stella.JSSystem;
import java.util.Vector;
import java.io.File;
import stella.SharedRegistry;
import java.util.Timer;

class VAuthEx implements VConsts
{
    private static final String filename_key = "jv.key";
    private static final String filename_reg = "jv.reg";
    private static final String filename_hst = ".javav.hst";
    private static final String filename_tsc = "licence.tsc";
    private static final boolean os_windows;
    private static final boolean os_unix;
    private static boolean client32;
    private static boolean remote_worker;
    private static int remote_worker_port;
    private static boolean ovf_converter;
    private static int ovf_converter_port;
    private static boolean initialized;
    private static boolean allusers;
    private static boolean restricted_user;
    private static boolean started;
    private static Timer timer;
    private static SharedRegistry sreg;
    private static final String PREFS_KEY_LIMITEDREGULAR_CONFIRM = "Yel403";
    private static final String PREFS_KEY_STARTING_BASETIME = "UeNL1fag4";
    private static final String PREFS_KEY_INDIVIDUALITY_FACTOR = "riwh5i54609n";
    private static final String PREFS_KEY_INDIVIDUALITY_START = "lwihn381wai3";
    private static File dir_work;
    private static File dir_jv;
    private static File file_key;
    private static File file_reg;
    private static File file_hst;
    private static KEY key;
    private static REG reg;
    private static HST hst;
    private static Vector<String> cids;
    private static boolean user_properties_modified;
    private static Vector<UserProperties> user_properties;
    private static boolean super_regular;
    private static boolean authorizing;
    private static VAuthExLog log;
    private static final int crypt_key = 89;
    private static final int crypt_reg = 44;
    private static final String[][] fixed_keys;
    private static final int crypt_hst = 138;
    private static final long stamptime_hst;
    
    static {
        os_windows = (JSSystem.isWindows() && JSSystem.isWinagent());
        os_unix = JSSystem.isUnix();
        VAuthEx.client32 = false;
        VAuthEx.remote_worker = false;
        VAuthEx.remote_worker_port = 5001;
        VAuthEx.ovf_converter = false;
        VAuthEx.ovf_converter_port = 4990;
        VAuthEx.initialized = false;
        VAuthEx.allusers = false;
        VAuthEx.restricted_user = false;
        VAuthEx.started = false;
        VAuthEx.timer = null;
        VAuthEx.dir_work = null;
        VAuthEx.dir_jv = null;
        VAuthEx.file_key = null;
        VAuthEx.file_reg = null;
        VAuthEx.file_hst = null;
        VAuthEx.key = null;
        VAuthEx.reg = null;
        VAuthEx.hst = null;
        VAuthEx.cids = new Vector<>();
        VAuthEx.user_properties_modified = false;
        VAuthEx.user_properties = new Vector<>();
        VAuthEx.super_regular = false;
        VAuthEx.authorizing = false;
        VAuthEx.log = null;
        fixed_keys = new String[][] { new String[0], new String[0], { "CmdMarkReset" }, new String[0] };
        stamptime_hst = DT.year(40);
    }
    
    static final File dirJVision() {
        return (VAuthEx.key != null) ? new File(VAuthEx.key.path, "jvision") : null;
    }
    
    static final void client32() {
        VAuthEx.client32 = true;
    }
    
    static final void remoteWorker(int remote_worker_port) {
        VAuthEx.remote_worker = true;
        VAuthEx.remote_worker_port = remote_worker_port;
    }
    
    static final boolean isRunModeRemoteWorker() {
        return VAuthEx.remote_worker;
    }
    
    static final int getRemoteWorkerPort() {
        return VAuthEx.remote_worker_port;
    }
    
    static final void ovfConverter(int ovf_converter_port) {
        VAuthEx.ovf_converter = true;
        VAuthEx.ovf_converter_port = ovf_converter_port;
    }
    
    static final boolean isRunModeOVFConverter() {
        return VAuthEx.ovf_converter;
    }
    
    static final int getOVFConverterPort() {
        return VAuthEx.ovf_converter_port;
    }
    
    private static final void initialize() throws SecurityException {
        if (VAuthEx.initialized) {
            return;
        }
        if (!VAuthEx.remote_worker) {
            File file = new File(VAuthEx.os_windows ? VPath.getAllUsersHomeRoot() : VPath.getAllUsersHomeRootUnix(), "jv.key");
            if (file.exists()) {
                VAuthEx.dir_jv = file.getParentFile();
                VAuthEx.allusers = true;
                VAuthEx.restricted_user = (!VAuthEx.remote_worker && VAuthEx.os_windows && VAuthEx.allusers && !JSSystem.isWindowsAdministratorUser());
                File file2 = new File(VPath.getHomeRoot());
                if (!file2.exists()) {
                    file2.mkdirs();
                }
            }
            else {
                File file3 = new File(VPath.getHomeRoot(), "jv.key");
                if (file3.exists()) {
                    VAuthEx.dir_jv = file3.getParentFile();
                }
                else {
                    throw new SecurityException(Message.get(210) + "[00]");
                }
            }
        }
        VAuthEx.sreg = SharedRegistry.instance();
        VAuthEx.timer = new Timer();
        VAuthEx.initialized = true;
    }
    
    static final void start() {
        VClashLogger.getInstance().flushLogln("VAUTEXc " + VClashLogger.getProcessingLine());
        VAuthEx.authorizing = true;
        VAuthEx.dir_work = new File(System.getProperty("user.dir"));
        File file = new File(VAuthEx.dir_work, "licence.tsc");
        VAuthEx.log = new VAuthExLog(file);
        boolean filterError = true;
        SecurityException ex = null;
        try {
            initialize();
            VClashLogger.getInstance().flushLogln("VAUTEXc " + VClashLogger.getProcessingLine());
            boolean remote_worker = VAuthEx.remote_worker;
            if (!remote_worker) {
                VAuthEx.file_key = new File(VAuthEx.dir_jv, "jv.key");
                VAuthEx.file_reg = new File(VAuthEx.dir_jv, "jv.reg");
                VAuthEx.file_hst = new File(VAuthEx.dir_jv.getParentFile(), ".javav.hst");
                VAuthEx.log.println("jv.key exists: " + VAuthEx.file_key.exists());
                VAuthEx.log.println("jv.reg exists: " + VAuthEx.file_reg.exists());
                VAuthEx.log.println(".javav.hst exists: " + VAuthEx.file_hst.exists());
                VAuthEx.log.println();
                if (!VAuthEx.file_reg.exists() || !VAuthEx.file_hst.exists()) {
                    throw new SecurityException(Message.get(210) + "[01]");
                }
                VAuthEx.log.println("<<authentication initial parameters>>");
                VAuthEx.log.println("jv.key: " + VAuthEx.file_key.getAbsolutePath());
                VAuthEx.log.println("jv.reg: " + VAuthEx.file_reg.getAbsolutePath());
                VAuthEx.log.println(".javav.hst: " + VAuthEx.file_hst.getAbsolutePath());
                VAuthEx.log.println("allusers: " + VAuthEx.allusers);
                VAuthEx.log.println("restricted_user: " + VAuthEx.restricted_user);
                VAuthEx.log.println();
                VAuthEx.log.println("<<jv.key authentication start>>");
                VAuthEx.log.println("Stella Vision Version: " + StellaVisionInfo.getVersion());
                VAuthEx.log.println("java.home: " + System.getProperty("java.home"));
                VAuthEx.log.println("java.version: " + System.getProperty("java.version"));
                VAuthEx.key = new KEY(VAuthEx.file_key);
                VAuthEx.log.println("keytime: " + VAuthEx.key.keytime + " " + DT.strDateTime(VAuthEx.key.keytime));
                VAuthEx.log.println("name: " + VAuthEx.key.name);
                VAuthEx.log.println("company: " + VAuthEx.key.company);
                VAuthEx.log.println("installed path: " + VAuthEx.key.path);
                VAuthEx.log.println("cpu_isalist: " + VAuthEx.key.cpu_isalist);
                VAuthEx.log.println("os_name: " + VAuthEx.key.os_name);
                VAuthEx.log.println("os_version: " + VAuthEx.key.os_version);
                VAuthEx.log.println("os_arch: " + VAuthEx.key.os_arch);
                VAuthEx.log.println("user_name: " + VAuthEx.key.user_name);
                VAuthEx.log.println("user_home: " + VAuthEx.key.user_home);
                VAuthEx.log.println("user_region: " + VAuthEx.key.user_region);
                VAuthEx.log.println("user_language: " + VAuthEx.key.user_language);
                VAuthEx.log.println("licenceID: " + VAuthEx.key.getLicenceID());
                VAuthEx.log.println("user properties count: " + VAuthEx.user_properties.size());
                for (int i = 0; i < VAuthEx.user_properties.size(); ++i) {
                    UserProperties userProperties = (UserProperties)VAuthEx.user_properties.get(i);
                    VAuthEx.log.println("user properties " + (i + 1));
                    VAuthEx.log.println("  name: " + userProperties.getName());
                    VAuthEx.log.println("  needPassword: " + (userProperties.needPassword() ? "yes" : "no"));
                    VAuthEx.log.println("  password: " + (userProperties.needPassword() ? userProperties.getPassword() : ""));
                    VAuthEx.log.println("  commission: " + (userProperties.isCommissionAdministrator() ? "administrator" : (userProperties.isCommissionNormal() ? "normal" : "unknown")));
                }
                if (!VAuthEx.key.checkInvalidID()) {
                    throw new SecurityException(Message.get(211) + "[K2]");
                }
                if (!VAuthEx.key.check()) {
                    throw new SecurityException(Message.get(212) + "[K0]");
                }
                VAuthEx.log.println("OK");
                VAuthEx.log.println();
                VAuthEx.log.println("<<jv.reg authentication start>>");
                VAuthEx.reg = new REG(VAuthEx.file_reg);
                VAuthEx.log.println("licenceID: " + VAuthEx.reg.licenceID);
                VAuthEx.log.println("term_type: " + VAuthEx.reg.term_type);
                VAuthEx.log.println("term: " + VAuthEx.reg.term + " " + DT.strDateTime(VAuthEx.reg.term));
                VAuthEx.log.println("time_adjust: " + VAuthEx.reg.time_adjust);
                VAuthEx.log.println("run_mode: " + VAuthEx.reg.run_mode);
                VAuthEx.log.println("count: " + VAuthEx.reg.count);
                VAuthEx.log.println("title: " + VAuthEx.reg.title);
                VAuthEx.log.println("comment: " + VAuthEx.reg.comment);
                VAuthEx.log.println("cid: " + ((VAuthEx.reg.cid != null) ? VAuthEx.reg.cid : ""));
                VAuthEx.log.println("limited_regular: " + VAuthEx.reg.limited_regular);
                VAuthEx.log.println("memory_standard: " + VAuthEx.reg.memory_standard);
                VAuthEx.log.println("keys count: " + VAuthEx.reg.keyinfos.size());
                for (int j = 0; j < ((VAuthEx.reg.keyinfos.size() > 20) ? 10 : VAuthEx.reg.keyinfos.size()); ++j) {
                    VAuthEx.log.println("  " + (String)VAuthEx.reg.keyinfos.get(j));
                }
                VAuthEx.log.println("extend: " + VAuthEx.reg.extend);
                if (VAuthEx.reg.extend) {
                    VAuthEx.log.println("approved: " + VAuthEx.reg.approved);
                    VAuthEx.log.println("approved time: " + VAuthEx.reg.approved_time + " " + DT.strDateTime(VAuthEx.reg.approved_time));
                    VAuthEx.log.println("prefskey: " + VAuthEx.reg.prefskey);
                    VAuthEx.log.println("company: " + VAuthEx.reg.company);
                    VAuthEx.log.println("uniqueID: " + VAuthEx.reg.uniqueID);
                    VAuthEx.log.println("hashkey: " + VAuthEx.reg.hashkey);
                    VAuthEx.log.println("hash: " + VAuthEx.reg.hash);
                    VAuthEx.log.println("maintenance_term: " + VAuthEx.reg.maintenance_term + " " + DT.strDateTime(VAuthEx.reg.maintenance_term));
                }
                VClashLogger.getInstance().flushLogln("VAUTEXc " + VClashLogger.getProcessingLine());
                if (!VAuthEx.reg.check(VAuthEx.key)) {
                    throw new SecurityException(Message.get(212) + "[R0]");
                }
                addCIDs(VAuthEx.reg.getCompanyID());
                VAuthEx.log.println("OK");
                VAuthEx.log.println();
                if (VAuthEx.reg.licenceID.equalsIgnoreCase("aW5aUj-LKElFBt")) {
                    JSFileUtil.destruct(VAuthEx.file_key);
                    JSFileUtil.destruct(VAuthEx.file_reg);
                    System.exit(-999);
                }
                VClashLogger.getInstance().flushLogln("VAUTEXc " + VClashLogger.getProcessingLine());
                VAuthEx.log.println("<<.javav.hst authentication start>>");
                (VAuthEx.hst = new HST(VAuthEx.file_hst)).start();
                VAuthEx.hst.check(VAuthEx.reg);
                VAuthEx.log.println("start: " + VAuthEx.hst.start + " " + DT.strDateTime(VAuthEx.hst.start));
                VAuthEx.log.println("running: " + VAuthEx.hst.running);
                VAuthEx.log.println("laststart: " + VAuthEx.hst.laststart + " " + DT.strDateTime(VAuthEx.hst.laststart));
                VAuthEx.log.println("lastend: " + VAuthEx.hst.lastend + " " + DT.strDateTime(VAuthEx.hst.lastend));
                if (VAuthEx.reg.isRunModeViewer()) {
                    startViewer();
                }
                else if (VAuthEx.reg.isRunModeServer()) {
                    startServer();
                }
                else if (VAuthEx.reg.isRunModeUnApproved() || VAuthEx.reg.isRunModeStandaloneLicence()) {
                    startStandaloneLicence();
                }
                else if (VAuthEx.reg.isRunModeSuperEngineer()) {
                    startSuperEngineer();
                }
                long minute = DT.minute(7);
                VAuthEx.timer.schedule(new TimerTask() {
                    @Override
                    public void run() {
                        VAuthEx.hst.update();
                    }
                }, minute, minute);
                VAuthEx.log.println("hst update task start");
                Runtime.getRuntime().addShutdownHook(new Thread(new Runnable() {
                    @Override
                    public void run() {
                        VAuthEx.hst.end();
                    }
                }));
                try {
                    VAuthEx.reg.checkIndividuality();
                }
                catch (Exception ex2) {
                    VAuthEx.log.println("reg.checkIndividuality() exception occured.");
                    VAuthEx.log.println("* exception * " + ex2.getLocalizedMessage());
                }
            }
            if (VAuthEx.ovf_converter) {
                VOVFConverter.startWaitingExternalCommand(VAuthEx.ovf_converter, VAuthEx.ovf_converter_port, VAuthEx.remote_worker);
            }
            StringBuilder o = new StringBuilder();
            o.append("<<<<");
            if (!remote_worker) {
                if (VAuthEx.reg.isRunModeViewer()) {
                    o.append("VIEWER");
                }
                else if (VAuthEx.reg.isRunModeServer()) {
                    o.append("FLOATING LICENCE");
                }
                else if (VAuthEx.reg.isRunModeTrial()) {
                    o.append("TRIAL");
                }
                else if (VAuthEx.reg.isRunModeRegular()) {
                    o.append("REGULAR");
                }
                else if (VAuthEx.reg.isRunModeLimitedRegular()) {
                    o.append("LIMITED REGULAR");
                }
                else if (VAuthEx.reg.isRunModeSuperEngineer()) {
                    o.append("SUPER ENGINEER");
                }
            }
            else if (VAuthEx.remote_worker) {
                o.append("REMOTE WORKER LICENCE");
            }
            if (VAuthEx.ovf_converter) {
                o.append(" (OVF CONVERTER)");
            }
            o.append(" VERSION>>>>   [");
            if (!VAuthEx.restricted_user) {
                o.append("Administrator Control");
            }
            else {
                o.append("Restriction User Control");
            }
            o.append("]");
            System.out.println();
            System.out.println(o.toString());
            System.out.println();
            System.out.println("Licence agreement.");
            VAuthEx.log.println(o.toString());
            VAuthEx.log.println();
            VAuthEx.log.println("Licence agreement.");
        }
        catch (SecurityException ex3) {
            JOptionPane.showInputDialog("类名", ex3.getStackTrace()[0].getClassName() + ex3.getStackTrace()[0].getLineNumber());
            VAuthEx.log.println(ex3.getMessage());
            filterError = filterError(ex3);
            ex = ex3;
        }
        finally {
            int collateFP2nd = JVWMI.isCollateFP2nd() ? 1 : 0;
            if (collateFP2nd != 0) {
                Preferences node = Preferences.userRoot().node(VAuthEx.reg.hash);
                int int1 = node.getInt("collateFP2nd", 0);
                if (int1 < 5) {
                    JVWMI.__cu9b8u43q();
                    VAuthEx.log.println(JVWMI.__euiot43742(VAuthEx.reg.hashkey, VAuthEx.reg.hash));
                }
                else {
                    collateFP2nd = 0;
                }
                node.putInt("collateFP2nd", int1 + 1);
            }
            VAuthEx.log.end();
            VAuthEx.log = null;
            if (collateFP2nd != 0) {
                File dest = new File(VAuthEx.dir_work, "licenceA.tsc");
                file.renameTo(dest);
                JSMessageDialog.informationOK(null, null, 272, new Object[] { dest.getAbsolutePath() });
                DesktopUtil.openFolder(VAuthEx.dir_work);
            }
            VAuthEx.authorizing = false;
        }
        if (ex != null) {
            if (filterError) {
                JSMessageDialog.errorOK(null, null, 213, new Object[] { ex.getMessage() });
                if (file.exists()) {
                    JSMessageDialog.informationOK(null, null, 270, new Object[] { file.getAbsolutePath() });
                    DesktopUtil.openFolder(file);
                }
            }
            if (file.exists()) {
                String format = String.format("%s_%s", new Object[] { "licence.tsc", DT.strDateTimeFilename(System.currentTimeMillis()) });
                File o2 = new File(VAuthEx.dir_work, format);
                File o3 = new File(JSSystem.getHomeDir(), format);
                JSFileUtil.copy(file, o2, true);
                JSFileUtil.copy(file, o3, true);
            }
            System.exit(-1);
        }
        VAuthEx.started = true;
    }
    
    private static boolean filterError(SecurityException ex) {
        boolean n = true;
        String message = ex.getMessage();
        if (message.indexOf("[TR1]") != -1) {
            n = false;
        }
        else if (message.indexOf("[LR0]") != -1) {
            n = false;
        }
        else if (message.indexOf("[SV0]") != -1) {
            n = false;
        }
        else if (message.indexOf("[SV3]") != -1) {
            n = false;
        }
        return n;
    }
    
    private static File createFPV(boolean b) {
        File file = new File(VPath.getAppRoot(), "LICENCE.FPV");
        if (file.exists() && System.currentTimeMillis() - file.lastModified() <= DT.day(3)) {
            return file;
        }
        String access$4700 = VAuthEx.reg.toStringExtra(b);
        JVWMI.setTargetDriveLetter(VAuthEx.key.path.charAt(0));
        return JVWMI.writeFP(file, access$4700) ? file : null;
    }
    
    private static final void startViewer() throws SecurityException {
    }
    
    private static final void startServer() throws SecurityException {
        JVWMICtrl.binding = false;
        VAuthEx.log.println("memory check...");
        VAuthEx.log.println("  max: " + JSSystem.getMaxMemory());
        VAuthEx.log.println("  used: " + JSSystem.getUsedMemory());
        VAuthEx.log.println("  free: " + JSSystem.getFreeMemory());
        if (!VAuthEx.reg.checkMaxMemory()) {
            throw new SecurityException(Message.get(258) + "[R4]");
        }
        VAuthEx.log.println("OK");
        logon();
    }
    
    private static final void logon() throws SecurityException {
        VClashLogger.getInstance().flushLogln("VAUTEXc " + VClashLogger.getProcessingLine());
        Bridge.setConfigurationPath(VPath.getAppBin());
        Bridge.setLogPath(VPath.getHomeRoot());
        if (!Bridge.isExistConfiguration()) {
            JSMessageDialog.warningOK(null, null, 950, new Object[] { Bridge.getConfigurationFile().getAbsolutePath() });
            throw new SecurityException(Message.get(231) + "[SV0]");
        }
        if (!Bridge.loadConfiguration()) {
            throw new SecurityException(Message.get(232) + "[SV1]");
        }
        if (!Bridge.canLogon()) {
            throw new SecurityException(Message.get(233) + "[SV2]");
        }
        Bridge.setBridgeConnectionListener(new BridgeConnectionListener() {
            public final void relogonFailed() {
                Vision.input().setInputDiabled(true);
            }
            
            public final void deadlineOver() {
                Vision.input().setInputDiabled(true);
            }
        });
        VClashLogger.getInstance().flushLogln("VAUTEXc " + VClashLogger.getProcessingLine());
        boolean logon = Bridge.logon(StellaVisionInfo.getVersion(), VSystemConfigManager.instance);
        VAuthEx.log.println("logon dialog brc: " + logon);
        if (logon) {
            int level = Bridge.getLevel();
            String keys = Bridge.getKeys();
            String companyID = Bridge.getCompanyID();
            VAuthEx.reg.setServerInfo((byte)level, keys);
            Vision.addCompanyID(companyID);
            VAuthEx.log.println("#1809-22397");
            VAuthEx.log.println("level: " + level);
            VAuthEx.log.println("keys: " + ((keys == null) ? "(null)" : (keys.isEmpty() ? "(empty)" : keys)));
            VAuthEx.log.println("cid: " + ((companyID == null) ? "(null)" : (companyID.isEmpty() ? "(empty)" : companyID)));
            return;
        }
        VAuthEx.log.println("logon dialog cancel throw SV3");
        throw new SecurityException("[SV3]");
    }
    
    private static final void logoff() {
        Bridge.logoff();
    }
    
    private static final void startStandaloneLicence() throws SecurityException {
        if (VAuthEx.reg.isRunModeUnApproved()) {
            File fpv = createFPV(false);
            if (fpv != null) {
                if (VAuthEx.allusers && VAuthEx.os_windows && !JSSystem.isWindowsActualAdministratorUser()) {
                    JSMessageDialog.warningOK(null, null, 263, new Object[0]);
                    System.exit(0);
                }
                UnApprovedDialog unApprovedDialog = new UnApprovedDialog(VAuthEx.reg, fpv, false);
                try {
                    unApprovedDialog.start();
                }
                finally {
                    unApprovedDialog.end();
                }
                System.exit(0);
            }
            else {
                throw new SecurityException(Message.get(214) + "[FPV0]");
            }
        }
        boolean access$1700 = VAuthEx.reg.extend;
        VAuthEx.reg.extend();
        if (!access$1700) {
            VAuthEx.log.println("jv.reg extended.");
            VAuthEx.log.println("  approved: " + VAuthEx.reg.approved);
            VAuthEx.log.println("  approved time: " + VAuthEx.reg.approved_time + " " + DT.strDateTime(VAuthEx.reg.approved_time));
            VAuthEx.log.println("  prefskey: " + VAuthEx.reg.prefskey);
            VAuthEx.log.println("  company: " + VAuthEx.reg.company);
            VAuthEx.log.println("  uniqueID: " + VAuthEx.reg.uniqueID);
            VAuthEx.log.println("  hashkey: " + VAuthEx.reg.hashkey);
            VAuthEx.log.println("  hash: " + VAuthEx.reg.hash);
            VAuthEx.log.println("  maintenance term: " + VAuthEx.reg.maintenance_term + " " + DT.strDateTime(VAuthEx.reg.maintenance_term));
        }
        if (!VAuthEx.reg.approved && !VAuthEx.super_regular) {
            File fpv2 = createFPV(true);
            if (fpv2 != null) {
                if (VAuthEx.allusers && VAuthEx.os_windows && !JSSystem.isWindowsActualAdministratorUser()) {
                    JSMessageDialog.warningOK(null, null, 263, new Object[0]);
                    System.exit(0);
                }
                UnApprovedDialog o = new UnApprovedDialog(VAuthEx.reg, fpv2, true);
                try {
                    o.start();
                }
                finally {
                    o.end();
                }
                if (!VAuthEx.reg.checkTransferTerm()) {
                    throw new SecurityException(Message.get(234) + "[R3]");
                }
            }
            else {
                throw new SecurityException(Message.get(214) + "[FPV1]");
            }
        }
        VAuthEx.log.println("memory check...");
        VAuthEx.log.println("  max: " + JSSystem.getMaxMemory());
        VAuthEx.log.println("  used: " + JSSystem.getUsedMemory());
        VAuthEx.log.println("  free: " + JSSystem.getFreeMemory());
        if (!VAuthEx.reg.checkMaxMemory() && !VAuthEx.super_regular) {
            throw new SecurityException(Message.get(258) + "[R4]");
        }
        VAuthEx.log.println("OK");
        VAuthEx.log.println("preferences check...");
        if (!VAuthEx.reg.checkPrefs()) {
            throw new SecurityException(Message.get(221) + "[R5]");
        }
        VAuthEx.log.println("OK");
        VAuthEx.log.println("hash check...");
        VAuthEx.log.println("OK");
        if (VAuthEx.reg.isRunModeTrial()) {
            startTrial();
        }
        else if (VAuthEx.reg.isRunModeRegular()) {
            startRegular();
        }
        else if (VAuthEx.reg.isRunModeLimitedRegular()) {
            startLimitedRegular();
        }
    }
    
    private static final void startTrial() throws SecurityException {
        VAuthEx.log.println("already start check...");
        if (!trialCheckAlreadyStart()) {
            throw new SecurityException(Message.get(219) + "[TR0]");
        }
        VAuthEx.log.println("OK");
        if (VAuthEx.allusers && VAuthEx.os_windows && !JSSystem.isWindowsActualAdministratorUser()) {
            JSMessageDialog.warningOK(null, null, 263, new Object[0]);
        }
        TrialConfirmDialog trialConfirmDialog = new TrialConfirmDialog();
        try {
            trialConfirmDialog.start();
            if (trialConfirmDialog.isOver()) {
                throw new SecurityException(Message.get(225) + "[TR1]");
            }
        }
        finally {
            trialConfirmDialog.end();
        }
        VAuthEx.timer.schedule(new TimerTask() {
            @Override
            public void run() {
                VAuthEx.hst.update();
                if (!VAuthEx.hst.checkLimit(VAuthEx.reg.term_type, VAuthEx.reg.term)) {
                    ThreadEx.invokeAndWait(new Runnable() {
                        @Override
                        public void run() {
                            JSMessageDialog.warningOK(null, null, 226, new Object[0]);
                            Vision.command().limitOver();
                            Vision.input().setInputDiabled(true);
                        }
                    });
                }
            }
        }, 0L, DT.minute(5));
        VAuthEx.log.println("trial check task start");
    }
    
    private static final boolean trialCheckAlreadyStart() {
        boolean n = true;
        try {
            new Socket(InetAddress.getLocalHost(), 7774).close();
            n = false;
        }
        catch (IOException ex) {
            Thread thread = new Thread(new Runnable() {
                @Override
                public void run() {
                    try {
                        ServerSocket serverSocket = new ServerSocket(7774);
                        while (true) {
                            try {
                                serverSocket.accept().close();
                                serverSocket.close();
                                continue;
                            }
                            finally {}
                        }
                        serverSocket.close();
                    }
                    catch (Exception ex) {
                        return;
                    }
                }
            });
            thread.setDaemon(true);
            thread.setPriority(1);
            thread.start();
        }
        return n;
    }
    
    private static final void startRegular() throws SecurityException {
    }
    
    private static final void startLimitedRegular() throws SecurityException {
        boolean n = false;
        long n2 = VAuthEx.reg.term - System.currentTimeMillis();
        boolean n3 = !VAuthEx.hst.checkLimit(VAuthEx.reg.term_type, VAuthEx.reg.term);
        if (!n3) {
            if (VAuthEx.sreg.start(VAuthEx.reg.prefskey)) {
                int int1 = VAuthEx.sreg.getInt("Yel403", 0);
                long day = DT.day(31);
                long week = DT.week(2);
                long week2 = DT.week(1);
                if (int1 < 1 && n2 <= day) {
                    VAuthEx.sreg.putInt("Yel403", 1);
                    n = true;
                }
                else if (int1 < 2 && n2 <= week) {
                    VAuthEx.sreg.putInt("Yel403", 2);
                    n = true;
                }
                else if (int1 < 3 && n2 <= week2) {
                    n = true;
                }
                VAuthEx.sreg.end();
            }
        }
        else {
            n = true;
        }
        if (n) {
            if (VAuthEx.allusers && VAuthEx.os_windows && !JSSystem.isWindowsActualAdministratorUser()) {
                JSMessageDialog.warningOK(null, null, 263, new Object[0]);
                System.exit(0);
            }
            LimitedRegularConfirmDialog o = new LimitedRegularConfirmDialog(VAuthEx.reg.term, n3);
            try {
                o.start();
            }
            finally {
                o.end();
            }
        }
        if (n3) {
            throw new SecurityException(Message.get(229) + "[LR0]");
        }
        VAuthEx.timer.schedule(new TimerTask() {
            @Override
            public void run() {
                if (System.currentTimeMillis() > VAuthEx.reg.term) {
                    ThreadEx.invokeAndWait(new Runnable() {
                        @Override
                        public void run() {
                            JSMessageDialog.warningOK(null, null, 230, new Object[0]);
                            Vision.command().limitOver();
                            Vision.input().setInputDiabled(true);
                        }
                    });
                }
            }
        }, 0L, DT.minute(5));
        VAuthEx.log.println("limited regular check task start");
    }
    
    private static final void startSuperEngineer() throws SecurityException {
    }
    
    static final void end() {
        if (!VAuthEx.started) {
            return;
        }
        if (VAuthEx.remote_worker) {
            return;
        }
        if (VAuthEx.reg.isRunModeServer()) {
            logoff();
        }
        VAuthEx.key.update();
        VAuthEx.hst.end();
    }
    
    static final Object[] ls() {
        Vector<Integer> vector = new Vector<>();
        try {
            initialize();
            VAuthEx.file_key = new File(VAuthEx.dir_jv, "jv.key");
            VAuthEx.file_reg = new File(VAuthEx.dir_jv, "jv.reg");
            if (VAuthEx.file_key.exists() && VAuthEx.file_reg.exists()) {
                VAuthEx.key = new KEY(VAuthEx.file_key);
                if (VAuthEx.key.checkInvalidID() && VAuthEx.key.check()) {
                    VAuthEx.reg = new REG(VAuthEx.file_reg);
                    if (VAuthEx.reg.check(VAuthEx.key)) {
                        vector.addElement(Integer.valueOf(0));
                        vector.addElement(VAuthEx.file_key);
                        vector.addElement(VAuthEx.file_reg);
                        vector.addElement(VAuthEx.key.name);
                        vector.addElement(VAuthEx.key.company);
                        vector.addElement(VAuthEx.key.path);
                        vector.addElement(VAuthEx.key.getLicenceID());
                        vector.addElement(Integer.valueOf(VAuthEx.reg.run_mode));
                        vector.addElement(Boolean.valueOf(VAuthEx.reg.limited_regular));
                        vector.addElement(Integer.valueOf(VAuthEx.reg.term_type));
                        vector.addElement(Long.valueOf(VAuthEx.reg.term));
                        vector.addElement(Boolean.valueOf(VAuthEx.reg.memory_standard));
                        vector.addElement(Boolean.valueOf(VAuthEx.reg.extend));
                        vector.addElement(Boolean.valueOf(VAuthEx.reg.approved));
                        vector.addElement(Long.valueOf(VAuthEx.reg.approved_time));
                        vector.addElement(VAuthEx.reg.prefskey);
                        vector.addElement(VAuthEx.reg.company);
                        vector.addElement(VAuthEx.reg.uniqueID);
                        vector.addElement(Long.valueOf(VAuthEx.reg.hashkey));
                        vector.addElement(VAuthEx.reg.hash);
                        vector.addElement(Long.valueOf(VAuthEx.reg.maintenance_term));
                        vector.addElement(Boolean.valueOf(VAuthEx.reg.b1));
                        vector.addElement(Boolean.valueOf(VAuthEx.reg.b2));
                        vector.addElement(Integer.valueOf(VAuthEx.reg.i1));
                        vector.addElement(Integer.valueOf(VAuthEx.reg.i2));
                        vector.addElement(Long.valueOf(VAuthEx.reg.l1));
                        vector.addElement(Long.valueOf(VAuthEx.reg.l2));
                    }
                }
            }
        }
        catch (SecurityException ex) {}
        return (Object[])(vector.isEmpty() ? null : vector.toArray());
    }
    
    static final void clean() {
        File[] listFiles = new File(new File(JSSystem.getHomeDir(), "jv"), "users").listFiles();
        if (listFiles != null) {
            for (int i = 0; i < listFiles.length; ++i) {
                JSFileUtil.deleteFiles(listFiles[i], "*.*", true, true);
            }
        }
        File[] listFiles2 = new File(new File(JSSystem.getWindowsAllUsersFolder(), "jv"), "users").listFiles();
        if (listFiles2 != null) {
            for (int j = 0; j < listFiles2.length; ++j) {
                JSFileUtil.deleteFiles(listFiles2[j], "*.*", true, true);
            }
        }
    }
    
    static final String ck(File file, String str, String str2, String str3) {
        String licenceID;
        try {
            DataOutputStream dataOutputStream = new DataOutputStream(new JSCryptOutputStream(new FileOutputStream(file), 89));
            try {
                Random random = new Random();
                dataOutputStream.writeDouble(random.nextDouble());
                dataOutputStream.writeUTF(str);
                dataOutputStream.writeUTF(str2);
                dataOutputStream.writeUTF(str3);
                dataOutputStream.writeDouble(random.nextDouble());
                String property = System.getProperty("sun.cpu.isalist");
                String property2 = System.getProperty("os.name");
                String property3 = System.getProperty("os.version");
                String property4 = System.getProperty("os.arch");
                String property5 = System.getProperty("user.name");
                String property6 = System.getProperty("user.home");
                String property7 = System.getProperty("user.region");
                String property8 = System.getProperty("user.language");
                dataOutputStream.writeUTF((property != null && property.length() > 0) ? property : "Unknown cpu");
                dataOutputStream.writeUTF(property2);
                dataOutputStream.writeUTF(property3);
                dataOutputStream.writeUTF(property4);
                dataOutputStream.writeUTF(property5);
                dataOutputStream.writeUTF(property6);
                dataOutputStream.writeUTF((property7 != null && property7.length() > 0) ? property7 : "Unknown region");
                dataOutputStream.writeUTF(property8);
                dataOutputStream.writeInt(0);
                dataOutputStream.writeInt(0);
                dataOutputStream.writeInt(0);
                dataOutputStream.writeUTF("");
            }
            finally {
                dataOutputStream.close();
            }
            licenceID = new KEY(file).getLicenceID();
        }
        catch (Exception ex) {
            throw new CodeException(-201, "*exception* could not key file. " + ex.getLocalizedMessage());
        }
        return licenceID;
    }
    
    static final void cr(File file, String str, int v, boolean v2) {
        String[] array = { "CmdSetLayers", "CmdBlockManager", "CmdObjectInspect", "CmdDistanceInspect", "CmdAngleInspect", "CmdPointInspect", "CmdClearanceInspect", "CmdBlockInspect", "CmdSetLayers", "CmdBlockManager", "CmdObjectInspect", "CmdDistanceInspect", "CmdAngleInspect", "CmdPointInspect", "CmdClearanceInspect", "CmdBlockInspect", "CmdMarkReset" };
        String[] array2 = (String[])((v == 2) ? array : null);
        int v3 = (array2 != null) ? array2.length : 0;
        try {
            DataOutputStream o = new DataOutputStream(new JSCryptOutputStream(new FileOutputStream(file), 44));
            try {
                Random o2 = new Random();
                o.writeDouble(o2.nextDouble());
                o.writeUTF(str);
                o.writeDouble(o2.nextDouble());
                o.writeInt(0);
                o.writeLong(0L);
                o.writeDouble(o2.nextDouble());
                o.writeLong(0L);
                o.writeDouble(o2.nextDouble());
                o.writeInt(v);
                o.writeDouble(o2.nextDouble());
                o.writeInt(v3);
                for (int i = 0; i < v3; ++i) {
                    o.writeDouble(o2.nextDouble());
                    o.writeUTF(array2[i]);
                }
                o.writeDouble(o2.nextDouble());
                o.writeUTF("");
                o.writeDouble(o2.nextDouble());
                o.writeUTF("");
                o.writeDouble(o2.nextDouble());
                o.writeUTF("");
                o.writeBoolean(false);
                o.writeBoolean(false);
                o.writeInt(0);
                o.writeBoolean(v2);
                o.writeBoolean(false);
                o.writeLong(0L);
                o.writeUTF("");
                o.writeUTF("");
                o.writeUTF("");
                o.writeLong(0L);
                o.writeUTF("");
                o.writeLong(0L);
                o.writeLong(0L);
            }
            finally {
                o.close();
            }
        }
        catch (Exception ex) {
            throw new CodeException(-202, "*exception* could not reg file. " + ex.getLocalizedMessage());
        }
    }
    
    static final void ch(File file) {
        try {
            DataOutputStream dataOutputStream = new DataOutputStream(new JSCryptOutputStream(new FileOutputStream(file), 138));
            try {
                Random random = new Random();
                dataOutputStream.writeDouble(random.nextDouble());
                dataOutputStream.writeLong(0L);
                dataOutputStream.writeDouble(random.nextDouble());
                dataOutputStream.writeLong(System.currentTimeMillis());
                dataOutputStream.writeLong(System.currentTimeMillis());
                dataOutputStream.writeDouble(random.nextDouble());
            }
            finally {
                dataOutputStream.close();
                Thread.sleep(100L);
                file.setLastModified(VAuthEx.stamptime_hst);
            }
        }
        catch (Exception ex) {
            throw new CodeException(-203, "*exception* could not hst file. " + ex.getLocalizedMessage());
        }
    }
    
    static final int r6(File file, File file2, String[] array, PrintStream printStream) {
        KEY key = new KEY(file);
        printStream.println("LicenceID: " + key.getLicenceID());
        printStream.println("OS Arch: " + System.getProperty("os.arch"));
        boolean access$200 = key.checkInvalidID();
        boolean access$201 = key.check();
        printStream.println("key.checkInvalidID(): " + access$200);
        printStream.println("key.check(): " + access$201);
        if (access$200 && access$201) {
            REG reg = new REG(file2);
            printStream.println("REG.extend: " + reg.extend);
            if (reg.extend) {
                boolean access$202 = reg.check(key);
                printStream.println("reg.check(): " + access$202);
                if (access$202) {
                    if (reg.isRunModeUnApproved()) {
                        printStream.println("reg.run_mode: UnApproved");
                    }
                    else if (reg.isRunModeViewer()) {
                        printStream.println("reg.run_mode: Viewer");
                    }
                    else if (reg.isRunModeServer()) {
                        printStream.println("reg.run_mode: Server");
                    }
                    else if (reg.isRunModeTrial()) {
                        printStream.println("reg.run_mode: Trial");
                    }
                    else if (reg.isRunModeRegular()) {
                        printStream.println("reg.run_mode: Regular");
                    }
                    else if (reg.isRunModeLimitedRegular()) {
                        printStream.println("reg.run_mode: Limited Regular");
                    }
                    else if (reg.isRunModeLimitedRegular()) {
                        printStream.println("reg.run_mode: Limited Regular");
                    }
                    else if (reg.isRunModeSuperEngineer()) {
                        printStream.println("reg.run_mode: Super Engineer");
                    }
                    else {
                        printStream.println("reg.run_mode: Unknown");
                    }
                    if (!reg.isRunModeUnApproved()) {
                        printStream.println("reg.approved: " + reg.approved);
                        if (reg.approved || reg.isRunModeSuperEngineer()) {
                            boolean access$203 = reg.checkMaxMemory();
                            printStream.println("reg.checkMaxMemory: " + access$203);
                            if (access$203) {
                                boolean access$204 = reg.checkHash(key);
                                printStream.println("reg.checkHash: " + access$204);
                                if (!access$204) {
                                    JSMessageDialog.informationOK(null, null, 0, new Object[] { "R6 license error was detected. Proceed to recovery steps." });
                                    return r6r(key, reg, array);
                                }
                                return 0;
                            }
                            else {
                                return -6;
                            }
                        }
                        else {
                            return -5;
                        }
                    }
                    else {
                        return -4;
                    }
                }
                else {
                    return -3;
                }
            }
            else {
                return -2;
            }
        }
        else {
            return -1;
        }
    }
    
    private static final int r6r(KEY key, REG reg, String[] array) {
        File file = new File(VPath.getAppRoot(), "LICENCE.FPV");
        File dest = new File(VPath.getAppRoot(), "LICENCE.FPV.R6");
        if (file.exists()) {
            if (dest.exists()) {
                dest.delete();
            }
            file.renameTo(dest);
        }
        String access$4700 = reg.toStringExtra(true);
        JVWMI.setTargetDriveLetter(key.path.charAt(0));
        if (JVWMI.writeFP(file, access$4700)) {
            JSMessageDialog.informationOK(null, null, 0, new Object[] { String.format("Please send us the %s file created in the folder. We will send you an %s file.", new Object[] { "LICENCE.FPV", "AUTHORIZATION.VAF" }) });
            DesktopUtil.openFolder(file);
            ThreadEx.sleeping(1000L);
            while (JSMessageDialog.informationYesNo(null, null, 0, new Object[] { String.format("Did you receive the %s file? If received, specify the file in the file selection dialog.", new Object[] { "AUTHORIZATION.VAF" }) }) != 2) {
                JSMessageDialog.informationOK(null, null, 0, new Object[] { "Apologies for making you wait. Please wait for a while until it arrives." });
                ThreadEx.sleeping(1000L);
            }
            FileFilter fileFilter = new FileFilter() {
                @Override
                public boolean accept(File file) {
                    if (file.isDirectory()) {
                        return true;
                    }
                    String name = file.getName();
                    int lastIndex = name.lastIndexOf(46);
                    return lastIndex > 0 && name.substring(lastIndex).equalsIgnoreCase(".VAF");
                }
                
                @Override
                public String getDescription() {
                    return "AUTHORIZATION.VAF";
                }
            };
            JFileChooser fileChooser = new JFileChooser();
            fileChooser.setDialogTitle("AUTHORIZATION.VAF");
            fileChooser.setDialogType(0);
            fileChooser.setFileSelectionMode(0);
            fileChooser.setMultiSelectionEnabled(false);
            fileChooser.setFileFilter(fileFilter);
            fileChooser.setCurrentDirectory(file.getParentFile());
            if (fileChooser.showOpenDialog(null) == 0) {
                File selectedFile = fileChooser.getSelectedFile();
                try {
                    reg.apply(new VAF(reg.licenceID, selectedFile), true);
                    return reg.checkHash(key) ? 1 : 5;
                }
                catch (SecurityException ex) {
                    array[0] = ex.getLocalizedMessage();
                    return 4;
                }
            }
            return 3;
        }
        else {
            return 2;
        }
    }
    
    static final JMenuItem createLicenceUpdateMenu() {
        return new LicenceUpdateMenuItem();
    }
    
    static final JMenuItem createViewerLicenceUpdateMenu() {
        return new ViewerLicenceUpdateMenuItem();
    }
    
    private static final void updateBin(boolean b) {
        if (Boolean.getBoolean("debug.vaf.mx")) {
            System.out.println(String.format("updateBin()", new Object[0]));
        }
        if (Boolean.getBoolean("debug.vaf.mx")) {
            System.out.println(String.format("reset_mx:%s", new Object[] { Boolean.valueOf(b) }));
        }
        int archDataModel = JSSystem.getArchDataModel();
        File file = new File(VPath.getAppBin(), "jvwin" + archDataModel + ".bat");
        if (file.exists()) {
            ArrayList list = new ArrayList<>();
            if (JSFileUtil.loadAsStringList(list, file)) {
                for (int i = 0; i < list.size(); ++i) {
                    String s = (String)list.get(i);
                    if (s.toLowerCase().indexOf("java.exe") != -1 && s.toLowerCase().indexOf("-jar") != -1) {
                        String s2 = null;
                        String[] split = JSStringUtil.split(s, ' ', true);
                        ArrayList<String> o = new ArrayList<>();
                        int j = -1;
                        int k = 0;
                        while (k < split.length) {
                            if (split[k].equals("-jar")) {
                                j = k;
                                break;
                            }
                            else {
                                if (split[k].startsWith("-Xmx")) {
                                    s2 = split[k];
                                }
                                else if (split[k].startsWith("-mx")) {
                                    s2 = split[k];
                                }
                                else {
                                    o.add(split[k]);
                                }
                                ++k;
                            }
                        }
                        if (VAuthEx.reg.run_mode != 3) {
                            String s3 = "1222M";
                            if (archDataModel == 64) {
                                switch (VAuthEx.reg.run_mode) {
                                    case 2: {
                                        s3 = "150G";
                                        break;
                                    }
                                    case 0:
                                    case 1: {
                                        s3 = (VAuthEx.reg.memory_standard ? "4G" : "150G");
                                        break;
                                    }
                                }
                            }
                            if (Boolean.getBoolean("debug.vaf.mx")) {
                                System.out.println("** " + file.getAbsolutePath());
                            }
                            if (Boolean.getBoolean("debug.vaf.mx")) {
                                System.out.println(String.format("def_mx:%s", new Object[] { (s2 == null) ? "none" : s2 }));
                            }
                            if (Boolean.getBoolean("debug.vaf.mx")) {
                                System.out.println((b || s2 == null) ? ("reset -mx" + s3) : ("inherit " + s2));
                            }
                            if (b || s2 == null) {
                                o.add("-mx" + s3);
                            }
                            else {
                                o.add(s2);
                            }
                        }
                        while (j < split.length) {
                            o.add(split[j]);
                            ++j;
                        }
                        StringBuilder o2 = new StringBuilder();
                        for (int l = 0, size = o.size(); l < size; ++l) {
                            o2.append((String)o.get(l));
                            if (l < size - 1) {
                                o2.append(' ');
                            }
                        }
                        list.set(i, o2.toString());
                    }
                }
                JSFileUtil.saveAsStringList(list, file);
            }
        }
        File o3 = new File(VPath.getAppBin(), "SV.INI");
        if (o3.exists()) {
            ArrayList o4 = new ArrayList<>();
            if (JSFileUtil.loadAsStringList(o4, o3)) {
                String s4 = null;
                ArrayList o5 = new ArrayList<>();
                int index = -1;
                int index2 = 0;
                while (index2 < o4.size()) {
                    String e = (String)o4.get(index2);
                    if (e.equals("---")) {
                        index = index2;
                        break;
                    }
                    else {
                        if (e.startsWith("-Xmx")) {
                            s4 = e;
                        }
                        else if (e.startsWith("-mx")) {
                            s4 = e;
                        }
                        else {
                            o5.add(e);
                        }
                        ++index2;
                    }
                }
                if (VAuthEx.reg.run_mode != 3) {
                    String s5 = "1222M";
                    if (archDataModel == 64) {
                        switch (VAuthEx.reg.run_mode) {
                            case 2: {
                                s5 = "150G";
                                break;
                            }
                            case 0:
                            case 1: {
                                s5 = (VAuthEx.reg.memory_standard ? "4G" : "150G");
                                break;
                            }
                        }
                    }
                    if (Boolean.getBoolean("debug.vaf.mx")) {
                        System.out.println("** " + o3.getAbsolutePath());
                    }
                    if (Boolean.getBoolean("debug.vaf.mx")) {
                        System.out.println(String.format("def_mx:%s", new Object[] { (s4 == null) ? "none" : s4 }));
                    }
                    if (Boolean.getBoolean("debug.vaf.mx")) {
                        System.out.println((b || s4 == null) ? ("reset -mx" + s5) : ("inherit " + s4));
                    }
                    if (b || s4 == null) {
                        o5.add("-mx" + s5);
                    }
                    else {
                        o5.add(s4);
                    }
                }
                if (index != -1) {
                    while (index < o4.size()) {
                        o5.add(o4.get(index));
                        ++index;
                    }
                }
                JSFileUtil.saveAsStringList(o5, o3);
            }
        }
    }
    
    static final boolean isRestrictedUser() {
        return VAuthEx.restricted_user;
    }
    
    static final String getName() {
        return (VAuthEx.key != null) ? VAuthEx.key.name : "";
    }
    
    static final String getCompany() {
        return (VAuthEx.key != null) ? VAuthEx.key.company : "";
    }
    
    static final String getLicenceID() {
        return (VAuthEx.key != null) ? VAuthEx.key.getLicenceID() : "";
    }
    
    static final void changeSetupInfo(String name, String company) {
        if (VAuthEx.key == null) {
            return;
        }
        VAuthEx.key.name = name;
        VAuthEx.key.company = company;
        modifiedUserProperties();
    }
    
    static final void updateKEY() {
        if (VAuthEx.key != null) {
            VAuthEx.key.update();
        }
    }
    
    static final boolean isRunModeViewer() {
        return VAuthEx.reg != null && VAuthEx.reg.isRunModeViewer();
    }
    
    static final boolean isRunModeServer() {
        return VAuthEx.reg != null && VAuthEx.reg.isRunModeServer();
    }
    
    static final boolean isRunModeTrial() {
        return VAuthEx.reg != null && VAuthEx.reg.isRunModeTrial();
    }
    
    static final boolean isRunModeRegular() {
        return VAuthEx.reg != null && VAuthEx.reg.isRunModeRegular();
    }
    
    static final boolean isRunModeLimitedRegular() {
        return VAuthEx.reg != null && VAuthEx.reg.isRunModeLimitedRegular();
    }
    
    static final boolean isRunModeSuperEngineer() {
        return VAuthEx.reg != null && VAuthEx.reg.isRunModeSuperEngineer();
    }
    
    static final boolean isAvailableCommand(String s) {
        return (VAuthEx.reg != null) ? VAuthEx.reg.isAvailableCommand(s) : VAuthEx.remote_worker;
    }
    
    static final void changeRunMode(int n) {
    }
    
    static final long getLimitedRegularTerm() {
        return (VAuthEx.reg != null) ? VAuthEx.reg.getLimitedRegularTerm() : 0L;
    }
    
    static final boolean isMemoryStandard() {
        return VAuthEx.reg != null && !VAuthEx.reg.isRunModeSuperEngineer() && VAuthEx.reg.isMemoryStandard();
    }
    
    static final String getTitle() {
        return (VAuthEx.reg != null) ? VAuthEx.reg.title : "";
    }
    
    static final String toStringCIDs() {
        StringBuilder sb = new StringBuilder();
        for (int i = 0, size = VAuthEx.cids.size(); i < size; ++i) {
            sb.append((String)VAuthEx.cids.get(i));
            if (i < size - 1) {
                sb.append(',');
            }
        }
        return sb.toString();
    }
    
    static final void addCIDs(String s) {
        if (s == null || s.isEmpty()) {
            return;
        }
        String[] split = s.split(",");
        for (int i = 0; i < split.length; ++i) {
            String s2 = split[i];
            if (!VAuthEx.cids.contains(s2)) {
                VAuthEx.cids.add(s2);
            }
            if (s2.equals("Stella_Debug") && !VAuthEx.cids.contains("Stella")) {
                VAuthEx.cids.add("Stella");
            }
        }
    }
    
    static final boolean includeCIDs(String s, boolean b) {
        boolean n = false;
        if (!b) {
            n = VAuthEx.cids.contains(s);
        }
        else {
            Iterator<String> iterator = VAuthEx.cids.iterator();
            while (iterator.hasNext()) {
                n = ((String)iterator.next()).equalsIgnoreCase(s);
                if (n) {
                    break;
                }
            }
        }
        return n;
    }
    
    static final void modifiedUserProperties() {
        VAuthEx.user_properties_modified = true;
    }
    
    static final int getUserPropertiesCount() {
        return VAuthEx.user_properties.size();
    }
    
    static final UserProperties getUserPropertiesAt(int index) {
        return (UserProperties)VAuthEx.user_properties.get(index);
    }
    
    static final void removeUserPropertiesAt(int index) {
        if (index != -1) {
            VAuthEx.user_properties.remove(index);
            VAuthEx.user_properties_modified = true;
        }
    }
    
    static final UserProperties findUserProperties(String anObject) {
        for (int i = VAuthEx.user_properties.size() - 1; i >= 0; --i) {
            UserProperties userProperties = (UserProperties)VAuthEx.user_properties.get(i);
            if (userProperties.getName().equals(anObject)) {
                return userProperties;
            }
        }
        return null;
    }
    
    static final void removeUserProperties(String anObject) {
        int n = -1;
        int i = VAuthEx.user_properties.size() - 1;
        while (i >= 0) {
            if (((UserProperties)VAuthEx.user_properties.get(i)).getName().equals(anObject)) {
                n = i;
                break;
            }
            else {
                --i;
            }
        }
        removeUserPropertiesAt(n);
    }
    
    static final UserProperties addUserProperties(String s, boolean b, String s2, int n) {
        UserProperties e = new UserProperties(s, b, s2, n);
        VAuthEx.user_properties.add(e);
        VAuthEx.user_properties_modified = true;
        return e;
    }
    
    static final boolean isStrictlyUserPropertiesControl() {
        String[] array = { "Stella", "LGE" };
        for (int i = array.length - 1; i >= 0; --i) {
            if (Vision.isCompanyID(array[i])) {
                return true;
            }
        }
        return false;
    }
    
    private static final class TrialConfirmDialog extends JSDialog implements ActionListener
    {
        private boolean over;
        private boolean time;
        private JLabel lblMessage;
        private JLabel lblVAF;
        private JButton btnApplyVAF;
        private SimpleDateFormat dtformat;
        
        private TrialConfirmDialog() {
            super(VRes.get("TrialVersion"), true);
            this.over = false;
            this.time = false;
            this.dtformat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
            this.over = !VAuthEx.hst.checkLimit(VAuthEx.reg.term_type, VAuthEx.reg.term);
            this.time = (VAuthEx.reg.term_type == 0);
            JPanel leftAccessory = new JPanel(new BorderLayout());
            JLabel comp = new JLabel(new ImageIcon(ClassLoader.getSystemResource("stella/resource/image/StellaLogo145x236.gif")));
            comp.setBorder(new EtchedBorder(1));
            leftAccessory.add(comp, "North");
            this.setLeftAccessory(leftAccessory);
            String s;
            if (this.time) {
                s = String.valueOf(DT.hours(VAuthEx.reg.term - System.currentTimeMillis())) + "H";
            }
            else {
                s = this.dtformat.format(Long.valueOf(VAuthEx.reg.term));
            }
            this.lblMessage = new JLabel(Message.get(this.over ? 224 : 223, new Object[] { s, "AUTHORIZATION.VAF" }));
            this.lblVAF = new JLabel("AUTHORIZATION.VAF" + Resource.get(":"));
            (this.btnApplyVAF = new JButton(Resource.get("Apply"))).addActionListener(this);
            if (VAuthEx.allusers && VAuthEx.os_windows) {
                this.btnApplyVAF.setEnabled(JSSystem.isWindowsActualAdministratorUser());
            }
            DM.start(this.panelUser);
            DM.add(this.lblMessage);
            DM.addReturn();
            DM.addIndent(20);
            DM.add(this.lblVAF, DM.defVCenter);
            DM.add(this.btnApplyVAF, DM.defVCenter);
            DM.end();
            this.panelUser.setBorder(new EmptyBorder(10, 10, 10, 10));
            this.setSystemButtons(new int[] { this.over ? 18 : 13 });
            leftAccessory.setBorder(new EmptyBorder((this.getContentPane().getPreferredSize().height - comp.getPreferredSize().height) / 2, 20, 10, 10));
        }
        
        public final void actionPerformed(ActionEvent actionEvent) {
            if (actionEvent.getSource() == this.btnApplyVAF) {
                this.doApplyVAF();
            }
        }
        
        private void doApplyVAF() {
            FileFilter fileFilter = new FileFilter() {
                @Override
                public boolean accept(File file) {
                    if (file.isDirectory()) {
                        return true;
                    }
                    String name = file.getName();
                    int lastIndex = name.lastIndexOf(46);
                    return lastIndex > 0 && name.substring(lastIndex).equalsIgnoreCase(".VAF");
                }
                
                @Override
                public String getDescription() {
                    return "AUTHORIZATION.VAF";
                }
            };
            JFileChooser fileChooser = new JFileChooser();
            fileChooser.setDialogTitle("AUTHORIZATION.VAF");
            fileChooser.setDialogType(0);
            fileChooser.setFileSelectionMode(0);
            fileChooser.setMultiSelectionEnabled(false);
            fileChooser.setFileFilter(fileFilter);
            fileChooser.setCurrentDirectory(new File(VPath.getAppRoot()));
            if (fileChooser.showOpenDialog(this.btnApplyVAF) == 0) {
                File selectedFile = fileChooser.getSelectedFile();
                try {
                    VAuthEx.reg.apply(new VAF(VAuthEx.reg.licenceID, selectedFile), false);
                    updateBin(true);
                    JSMessageDialog.informationOK(this, null, 54, new Object[0]);
                    this.dismiss(18);
                    System.exit(0);
                }
                catch (SecurityException ex) {
                    JSMessageDialog.errorOK(this, null, 217, new Object[] { ex.getMessage() });
                }
            }
        }
        
        public final boolean isOver() {
            return this.over;
        }
    }
    
    private static final class LimitedRegularConfirmDialog extends JSDialog implements ActionListener
    {
        private JLabel lblMessage;
        private JLabel lblVAF;
        private JButton btnApplyVAF;
        private SimpleDateFormat dtformat;
        
        private LimitedRegularConfirmDialog(long l, boolean b) {
            super(VRes.get("LimitedRegularVersion"), true);
            this.dtformat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
            JPanel leftAccessory = new JPanel(new BorderLayout());
            JLabel comp = new JLabel(new ImageIcon(ClassLoader.getSystemResource("stella/resource/image/StellaLogo145x236.gif")));
            comp.setBorder(new EtchedBorder(1));
            leftAccessory.add(comp, "North");
            this.setLeftAccessory(leftAccessory);
            this.lblMessage = new JLabel(Message.get(b ? 228 : 227, new Object[] { this.dtformat.format(Long.valueOf(l)), "AUTHORIZATION.VAF" }));
            this.lblVAF = new JLabel("AUTHORIZATION.VAF" + Resource.get(":"));
            (this.btnApplyVAF = new JButton(Resource.get("Apply"))).addActionListener(this);
            if (VAuthEx.allusers && VAuthEx.os_windows) {
                this.btnApplyVAF.setEnabled(JSSystem.isWindowsActualAdministratorUser());
            }
            DM.start(this.panelUser);
            DM.add(this.lblMessage);
            DM.addReturn();
            DM.addIndent(20);
            DM.add(this.lblVAF, DM.defVCenter);
            DM.add(this.btnApplyVAF, DM.defVCenter);
            DM.end();
            this.panelUser.setBorder(new EmptyBorder(10, 10, 10, 10));
            this.setSystemButtons(new int[] { b ? 18 : 13 });
            leftAccessory.setBorder(new EmptyBorder((this.getContentPane().getPreferredSize().height - comp.getPreferredSize().height) / 2, 20, 10, 10));
        }
        
        public final void actionPerformed(ActionEvent actionEvent) {
            if (actionEvent.getSource() == this.btnApplyVAF) {
                this.doApplyVAF();
            }
        }
        
        private void doApplyVAF() {
            FileFilter fileFilter = new FileFilter() {
                @Override
                public boolean accept(File file) {
                    if (file.isDirectory()) {
                        return true;
                    }
                    String name = file.getName();
                    int lastIndex = name.lastIndexOf(46);
                    return lastIndex > 0 && name.substring(lastIndex).equalsIgnoreCase(".VAF");
                }
                
                @Override
                public String getDescription() {
                    return "AUTHORIZATION.VAF";
                }
            };
            JFileChooser fileChooser = new JFileChooser();
            fileChooser.setDialogTitle("AUTHORIZATION.VAF");
            fileChooser.setDialogType(0);
            fileChooser.setFileSelectionMode(0);
            fileChooser.setMultiSelectionEnabled(false);
            fileChooser.setFileFilter(fileFilter);
            fileChooser.setCurrentDirectory(new File(VPath.getAppRoot()));
            if (fileChooser.showOpenDialog(this.btnApplyVAF) == 0) {
                File selectedFile = fileChooser.getSelectedFile();
                try {
                    VAuthEx.reg.apply(new VAF(VAuthEx.reg.licenceID, selectedFile), false);
                    updateBin(true);
                    JSMessageDialog.informationOK(this, null, 54, new Object[0]);
                    this.dismiss(18);
                    System.exit(0);
                }
                catch (SecurityException ex) {
                    JSMessageDialog.errorOK(this, null, 217, new Object[] { ex.getMessage() });
                }
            }
        }
    }
    
    private static class KEY
    {
        private File fkey;
        private long keytime;
        public String name;
        public String company;
        public String path;
        public String cpu_isalist;
        public String os_name;
        public String os_version;
        public String os_arch;
        public String user_name;
        public String user_home;
        public String user_region;
        public String user_language;
        
        private KEY(File fkey) throws SecurityException {
            this.fkey = fkey;
            try {
                DataInputStream dataInputStream = new DataInputStream(new JSCryptInputStream(new FileInputStream(this.fkey), 89));
                try {
                    this.keytime = fkey.lastModified();
                    dataInputStream.readDouble();
                    this.name = dataInputStream.readUTF();
                    this.company = dataInputStream.readUTF();
                    this.path = dataInputStream.readUTF();
                    dataInputStream.readDouble();
                    this.cpu_isalist = dataInputStream.readUTF();
                    this.os_name = dataInputStream.readUTF();
                    this.os_version = dataInputStream.readUTF();
                    this.os_arch = dataInputStream.readUTF();
                    this.user_name = dataInputStream.readUTF();
                    this.user_home = dataInputStream.readUTF();
                    this.user_region = dataInputStream.readUTF();
                    this.user_language = dataInputStream.readUTF();
                    try {
                        int int1 = dataInputStream.readInt();
                        if (int1 > 0) {
                            VAuthEx.user_properties.clear();
                            for (int i = 0; i < int1; ++i) {
                                UserProperties e = new UserProperties();
                                e.read(dataInputStream);
                                VAuthEx.user_properties.add(e);
                            }
                        }
                        dataInputStream.readInt();
                        for (int int2 = dataInputStream.readInt(), j = 0; j < int2; ++j) {
                            dataInputStream.read(new byte[dataInputStream.readInt()]);
                        }
                        dataInputStream.readUTF();
                    }
                    catch (EOFException ex3) {}
                    VPath.redefineAppBase(this.path);
                }
                finally {
                    dataInputStream.close();
                }
            }
            catch (Exception ex2) {
                if (!VAuthEx.authorizing && !(ex2 instanceof FileNotFoundException)) {
                    System.out.println("<KEX> " + ex2.getClass().getName());
                }
                throw new SecurityException(Message.get(210) + ex2.getMessage() + "[K1]");
            }
        }
        
        public String getLicenceID() {
            return new StringBuilder().append(this.cpu_isalist.charAt(0)).append(this.os_name.charAt(0)).append(this.os_version.charAt(0)).append(this.os_arch.charAt(0)).append(this.user_region.charAt(0)).append(this.user_language.charAt(0)).append("-").append(JSStringUtil.toString62(this.keytime)).toString();
        }
        
        private final boolean checkInvalidID() {
            boolean n = true;
            InputStream resourceAsStream = this.getClass().getResourceAsStream("VDidl.class");
            if (resourceAsStream != null) {
                try {
                    BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new JSCryptInputStream(resourceAsStream, 62)));
                    try {
                        String licenceID = this.getLicenceID();
                        while (true) {
                            String line = bufferedReader.readLine();
                            if (line == null) {
                                break;
                            }
                            else {
                                String trim = line.trim();
                                if (trim.length() == 0) {
                                    continue;
                                }
                                else if (trim.charAt(0) == '#') {
                                    continue;
                                }
                                else {
                                    String[] split = trim.split(";");
                                    split[0] = split[0].trim();
                                    if (split[0].equals(licenceID)) {
                                        n = false;
                                        break;
                                    }
                                    else {
                                        continue;
                                    }
                                }
                            }
                        }
                    }
                    finally {
                        bufferedReader.close();
                    }
                }
                catch (IOException ex) {
                    if (VAuthEx.log != null) {
                        VAuthEx.log.println("!!! exception !!! VDidl.class IOException " + ex.getMessage());
                    }
                }
            }
            return n;
        }
        
        private final boolean check() {
            String property = System.getProperty("os.arch");
            if (!property.equalsIgnoreCase(this.os_arch)) {
                if (VAuthEx.log != null) {
                    VAuthEx.log.println("os.arch difference error.");
                }
                if (VAuthEx.log != null) {
                    VAuthEx.log.println("key.os.arch: " + this.os_arch);
                }
                if (VAuthEx.log != null) {
                    VAuthEx.log.println("system.os.arch: " + property);
                }
                return false;
            }
            else {
                return true;
            }
        }
        
        private void update() {
            if (VAuthEx.restricted_user) {
                return;
            }
            if (!VAuthEx.user_properties_modified) {
                return;
            }
            Thread thread = new Thread() {
                @Override
                public void run() {
                    if (KEY.this.fkey.lastModified() != KEY.this.keytime) {
                        ThreadEx.sleeping(10L);
                        KEY.this.fkey.setLastModified(KEY.this.keytime);
                        if (Vision.isStellaUse()) {
                            JSMessageDialog.errorOK(null, null, 0, new Object[] { "jv.key更新時に異常発生。フックスレッドで補足し、ファイルの日付をもとに戻しておきました。" });
                        }
                    }
                }
            };
            Runtime.getRuntime().addShutdownHook(thread);
            try {
                FileOutputStream fileOutputStream = new FileOutputStream(this.fkey);
                try {
                    FileChannel channel = fileOutputStream.getChannel();
                    try {
                        FileLock fileLock;
                        for (fileLock = channel.tryLock(); fileLock == null; fileLock = channel.tryLock()) {
                            if (Vision.isStellaUse()) {
                                System.out.println("jv.keyは他のビジョンプロセスからアクセスされています。しばらく待機...");
                            }
                            ThreadEx.sleeping(500L);
                        }
                        try {
                            DataOutputStream o = new DataOutputStream(new JSCryptOutputStream(fileOutputStream, 89));
                            try {
                                Random o2 = new Random();
                                o.writeDouble(o2.nextDouble());
                                o.writeUTF(this.name);
                                o.writeUTF(this.company);
                                o.writeUTF(this.path);
                                o.writeDouble(o2.nextDouble());
                                o.writeUTF((this.cpu_isalist != null && this.cpu_isalist.length() > 0) ? this.cpu_isalist : "Unknown cpu");
                                o.writeUTF(this.os_name);
                                o.writeUTF(this.os_version);
                                o.writeUTF(this.os_arch);
                                o.writeUTF(this.user_name);
                                o.writeUTF(this.user_home);
                                o.writeUTF((this.user_region != null && this.user_region.length() > 0) ? this.user_region : "Unknown region");
                                o.writeUTF(this.user_language);
                                int size = VAuthEx.user_properties.size();
                                o.writeInt(size);
                                if (size > 0) {
                                    for (int i = 0; i < size; ++i) {
                                        ((UserProperties)VAuthEx.user_properties.get(i)).write(o);
                                    }
                                }
                                o.writeInt(1);
                                o.writeInt(0);
                                o.writeUTF("");
                                VAuthEx.user_properties_modified = false;
                            }
                            catch (Exception ex) {
                                if (Vision.isStellaUse()) {
                                    ex.printStackTrace();
                                }
                                throw ex;
                            }
                            catch (Error error) {
                                if (Vision.isStellaUse()) {
                                    error.printStackTrace();
                                }
                                throw error;
                            }
                        }
                        finally {
                            fileLock.release();
                        }
                    }
                    finally {
                        channel.close();
                    }
                }
                finally {
                    fileOutputStream.close();
                }
                Thread.sleep(10L);
                this.fkey.setLastModified(this.keytime);
            }
            catch (Exception ex2) {
                if (Vision.isStellaUse()) {
                    ex2.printStackTrace();
                }
                if (this.fkey.lastModified() != this.keytime) {
                    if (Vision.isStellaUse()) {
                        System.out.println("異常なキースタンプ : " + this.fkey.lastModified());
                        System.out.println("期待するキースタンプ : " + this.keytime);
                    }
                    ThreadEx.sleeping(10L);
                    this.fkey.setLastModified(this.keytime);
                    if (Vision.isStellaUse()) {
                        JSMessageDialog.errorOK(null, null, 0, new Object[] { "jv.key更新時に例外発生。ファイルの日付が異なっていましたので元に戻しておきました。" });
                    }
                }
                throw new SecurityException(ex2.getLocalizedMessage());
            }
            catch (Error error2) {
                if (Vision.isStellaUse()) {
                    error2.printStackTrace();
                }
                if (this.fkey.lastModified() != this.keytime) {
                    if (Vision.isStellaUse()) {
                        System.out.println("異常なキースタンプ : " + this.fkey.lastModified());
                        System.out.println("期待するキースタンプ : " + this.keytime);
                    }
                    ThreadEx.sleeping(10L);
                    this.fkey.setLastModified(this.keytime);
                    if (Vision.isStellaUse()) {
                        JSMessageDialog.errorOK(null, null, 0, new Object[] { "jv.key更新時に例外発生。ファイルの日付が異なっていましたので元に戻しておきました。" });
                    }
                }
                throw new SecurityException(error2.getLocalizedMessage());
            }
            finally {
                Runtime.getRuntime().removeShutdownHook(thread);
                if (this.fkey.lastModified() != this.keytime) {
                    if (Vision.isStellaUse()) {
                        System.out.println("異常なキースタンプ : " + this.fkey.lastModified());
                        System.out.println("期待するキースタンプ : " + this.keytime);
                    }
                    ThreadEx.sleeping(10L);
                    this.fkey.setLastModified(this.keytime);
                    if (Vision.isStellaUse()) {
                        JSMessageDialog.errorOK(null, null, 0, new Object[] { "jv.keyのファイルスタンプを再度確認してみましたが、異常が生じていたので元に戻しておきました。" });
                    }
                }
            }
        }
    }
    
    private static class REG
    {
        private File freg;
        private String licenceID;
        private int term_type;
        private long term;
        private long time_adjust;
        private int run_mode;
        private int count;
        private ArrayList<String> keyinfos;
        private String title;
        private String comment;
        private String cid;
        private boolean limited_regular;
        private boolean memory_standard;
        private boolean extend;
        private boolean approved;
        private long approved_time;
        private String prefskey;
        private String company;
        private String uniqueID;
        private long hashkey;
        private String hash;
        private long maintenance_term;
        private boolean b1;
        private boolean b2;
        private int i1;
        private int i2;
        private long l1;
        private long l2;
        private static final int INDIVIDUALITY_MAX_LEVEL = 4;
        private static final long[] INDIVIDUALITY_LEVEL_TERM;
        private int individuality_max_level;
        private int individuality_level;
        private String[] individuality;
        private byte level;
        
        static {
            INDIVIDUALITY_LEVEL_TERM = new long[] { DT.week(3), DT.month(2), DT.month(6), DT.month(12) };
        }
        
        private REG(File freg) throws SecurityException {
            this.keyinfos = new ArrayList<>();
            this.limited_regular = false;
            this.memory_standard = false;
            this.individuality_max_level = 4;
            this.individuality_level = 0;
            this.individuality = new String[this.individuality_max_level];
            this.freg = freg;
            try {
                DataInputStream dataInputStream = new DataInputStream(new JSCryptInputStream(new FileInputStream(this.freg), 44));
                try {
                    dataInputStream.readDouble();
                    this.licenceID = dataInputStream.readUTF();
                    dataInputStream.readDouble();
                    this.term_type = dataInputStream.readInt();
                    this.term = dataInputStream.readLong();
                    dataInputStream.readDouble();
                    this.time_adjust = dataInputStream.readLong();
                    dataInputStream.readDouble();
                    this.run_mode = dataInputStream.readInt();
                    if (this.run_mode == -1) {
                        if (Boolean.getBoolean("stella.vision.run.mode.server")) {
                            this.run_mode = 3;
                        }
                        else if (Boolean.getBoolean("stella.vision.run.mode.regular")) {
                            this.run_mode = 1;
                            VAuthEx.super_regular = true;
                        }
                    }
                    dataInputStream.readDouble();
                    this.count = dataInputStream.readInt();
                    for (int i = 0; i < this.count; ++i) {
                        dataInputStream.readDouble();
                        this.keyinfos.add(dataInputStream.readUTF());
                    }
                    this.title = "";
                    this.comment = "";
                    this.cid = null;
                    this.limited_regular = false;
                    this.memory_standard = false;
                    this.extend = false;
                    this.approved = false;
                    this.approved_time = 0L;
                    this.prefskey = "";
                    this.company = "";
                    this.uniqueID = "";
                    this.hashkey = 0L;
                    this.hash = "";
                    this.maintenance_term = 0L;
                    this.b1 = false;
                    this.b2 = false;
                    this.i1 = 0;
                    this.i2 = 0;
                    this.l1 = 0L;
                    this.l2 = 0L;
                    this.individuality_max_level = 4;
                    this.individuality_level = 0;
                    this.individuality = new String[this.individuality_max_level];
                    for (int j = 0; j < this.individuality_max_level; ++j) {
                        this.individuality[j] = "";
                    }
                    try {
                        dataInputStream.readDouble();
                        this.title = dataInputStream.readUTF();
                        dataInputStream.readDouble();
                        this.comment = dataInputStream.readUTF();
                        dataInputStream.readDouble();
                        this.cid = dataInputStream.readUTF();
                        if (this.cid.length() == 0) {
                            this.cid = null;
                        }
                        this.limited_regular = (dataInputStream.readBoolean() && this.run_mode == 1);
                        dataInputStream.readBoolean();
                        dataInputStream.readInt();
                        this.memory_standard = dataInputStream.readBoolean();
                        this.approved = dataInputStream.readBoolean();
                        this.approved_time = dataInputStream.readLong();
                        this.prefskey = dataInputStream.readUTF();
                        this.company = dataInputStream.readUTF();
                        this.uniqueID = dataInputStream.readUTF();
                        this.hashkey = dataInputStream.readLong();
                        this.hash = dataInputStream.readUTF();
                        this.maintenance_term = dataInputStream.readLong();
                        this.b1 = dataInputStream.readBoolean();
                        this.b2 = dataInputStream.readBoolean();
                        this.i1 = dataInputStream.readInt();
                        this.i2 = dataInputStream.readInt();
                        this.l1 = dataInputStream.readLong();
                        this.l2 = dataInputStream.readLong();
                        try {
                            this.individuality_max_level = dataInputStream.readInt();
                            this.individuality_level = dataInputStream.readInt();
                            for (int k = 0; k < this.individuality_max_level; ++k) {
                                this.individuality[k] = dataInputStream.readUTF();
                            }
                        }
                        catch (Exception ex4) {}
                        this.extend = true;
                    }
                    catch (Exception ex5) {}
                }
                finally {
                    dataInputStream.close();
                }
            }
            catch (Exception ex3) {
                if (!VAuthEx.authorizing && !(ex3 instanceof FileNotFoundException)) {
                    System.out.println("<REX> " + ex3.getClass().getName());
                }
                throw new SecurityException(Message.get(210) + ex3.getMessage() + "[R1]");
            }
        }
        
        private void apply(VAF vaf, boolean b) throws SecurityException {
            if (!this.licenceID.equals(vaf.licenceID)) {
                throw new SecurityException("*error* could not apply vaf. [VAF1]");
            }
            if (this.approved && this.hashkey == vaf.hashkey && !this.hash.equals(vaf.hash) && !b) {
                throw new SecurityException("*error* could not apply vaf. [VAF2]");
            }
            this.licenceID = vaf.licenceID;
            switch (this.run_mode = vaf.runMode) {
                case 0: {
                    this.term = (vaf.trialTermInc ? (System.currentTimeMillis() + vaf.trialTerm) : vaf.trialTerm);
                    this.term_type = 1;
                    break;
                }
                case 1: {
                    this.limited_regular = vaf.limitedRegular;
                    this.term = 0L;
                    this.term_type = 1;
                    if (this.limited_regular) {
                        this.term = (vaf.regularTermInc ? (System.currentTimeMillis() + vaf.regularTerm) : vaf.regularTerm);
                        break;
                    }
                    else {
                        break;
                    }
                }
            }
            this.time_adjust = vaf.timeAdjust;
            this.cid = vaf.cid;
            this.memory_standard = vaf.memoryStandard;
            this.keyinfos.clear();
            String[] split = vaf.menukeys.split(";");
            for (int i = 0; i < split.length; ++i) {
                this.keyinfos.add(split[i]);
            }
            this.count = this.keyinfos.size();
            this.title = vaf.title;
            this.comment = vaf.comment;
            this.company = vaf.company;
            this.uniqueID = vaf.uniqueID;
            this.hashkey = vaf.hashkey;
            this.hash = vaf.hash;
            this.maintenance_term = vaf.maintenance_term;
            this.b1 = vaf.b1;
            this.b2 = vaf.b2;
            this.i1 = vaf.i1;
            this.i2 = vaf.i2;
            this.l1 = vaf.l1;
            this.l2 = vaf.l2;
            if (!this.approved) {
                this.approved = true;
                this.approved_time = System.currentTimeMillis();
                this.prefskey = this.prefskey();
                this.individuality_max_level = 4;
                this.individuality_level = 0;
                this.individuality = new String[this.individuality_max_level];
                for (int j = 0; j < this.individuality_max_level; ++j) {
                    this.individuality[j] = "";
                }
            }
            this.save();
        }
        
        private void apply(MNU mnu) throws SecurityException {
            this.keyinfos.clear();
            String[] split = mnu.menukeys.split(";");
            for (int i = 0; i < split.length; ++i) {
                this.keyinfos.add(split[i]);
            }
            this.count = this.keyinfos.size();
            this.save();
        }
        
        private String prefskey() {
            String string = "B0285C-" + UUID.randomUUID().toString();
            if (VAuthEx.sreg.start(string)) {
                VAuthEx.sreg.putInt("Yel403", 0);
                VAuthEx.sreg.putLong("UeNL1fag4", System.currentTimeMillis());
                VAuthEx.sreg.putLong("riwh5i54609n", 0L);
                VAuthEx.sreg.putLong("lwihn381wai3", System.currentTimeMillis());
                VAuthEx.sreg.end();
            }
            return string;
        }
        
        private void extend() throws SecurityException {
            if (this.extend) {
                return;
            }
            this.approved = false;
            this.approved_time = System.currentTimeMillis() + DT.day(31);
            this.prefskey = this.prefskey();
            this.company = "";
            this.uniqueID = "";
            this.hashkey = 0L;
            this.hash = "";
            this.maintenance_term = 0L;
            this.b1 = false;
            this.b2 = false;
            this.i1 = 0;
            this.i2 = 0;
            this.l1 = 0L;
            this.l2 = 0L;
            this.individuality_max_level = 4;
            this.individuality_level = 0;
            this.individuality = new String[this.individuality_max_level];
            for (int i = 0; i < this.individuality_max_level; ++i) {
                this.individuality[i] = "";
            }
            this.save();
            this.extend = true;
        }
        
        public final void save() throws SecurityException {
            File file = new File(this.freg.getParentFile(), "$" + this.freg.getName());
            if (file.exists()) {
                file.delete();
            }
            JSFileUtil.copy(this.freg, file, true);
            try {
                DataOutputStream dataOutputStream = new DataOutputStream(new JSCryptOutputStream(new FileOutputStream(this.freg), 44));
                try {
                    Random random = new Random();
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeUTF(this.licenceID);
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeInt(this.term_type);
                    dataOutputStream.writeLong(this.term);
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeLong(this.time_adjust);
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeInt(this.run_mode);
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeInt(this.count);
                    for (int i = 0; i < this.count; ++i) {
                        dataOutputStream.writeDouble(random.nextDouble());
                        dataOutputStream.writeUTF((String)this.keyinfos.get(i));
                    }
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeUTF(this.title);
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeUTF(this.comment);
                    dataOutputStream.writeDouble(random.nextDouble());
                    dataOutputStream.writeUTF((this.cid == null) ? "" : this.cid);
                    dataOutputStream.writeBoolean(this.limited_regular);
                    dataOutputStream.writeBoolean(false);
                    dataOutputStream.writeInt(0);
                    dataOutputStream.writeBoolean(this.memory_standard);
                    dataOutputStream.writeBoolean(this.approved);
                    dataOutputStream.writeLong(this.approved_time);
                    dataOutputStream.writeUTF(this.prefskey);
                    dataOutputStream.writeUTF(this.company);
                    dataOutputStream.writeUTF(this.uniqueID);
                    dataOutputStream.writeLong(this.hashkey);
                    dataOutputStream.writeUTF(this.hash);
                    dataOutputStream.writeLong(this.maintenance_term);
                    dataOutputStream.writeBoolean(this.b1);
                    dataOutputStream.writeBoolean(this.b2);
                    dataOutputStream.writeInt(this.i1);
                    dataOutputStream.writeInt(this.i2);
                    dataOutputStream.writeLong(this.l1);
                    dataOutputStream.writeLong(this.l2);
                    dataOutputStream.writeInt(this.individuality_max_level);
                    dataOutputStream.writeInt(this.individuality_level);
                    for (int j = 0; j < this.individuality_max_level; ++j) {
                        dataOutputStream.writeUTF(this.individuality[j]);
                    }
                }
                finally {
                    dataOutputStream.close();
                }
                if (!VAuthEx.restricted_user) {
                    this.freg.setWritable(true, false);
                }
            }
            catch (Exception ex) {
                throw new SecurityException(Message.get(220) + ex.getMessage() + "[R2]");
            }
        }
        
        private final String commandKey(String s) {
            String s2 = "";
            if (s != null && !s.isEmpty()) {
                int index = s.indexOf(",");
                s2 = ((index == -1) ? s : s.substring(0, index));
            }
            return s2;
        }
        
        private final long commandTerm(String s) {
            long long1 = 0L;
            if (s != null && !s.isEmpty()) {
                if (s.indexOf(",") == -1) {
                    long1 = 0L;
                }
                else {
                    String[] split = s.split(",");
                    try {
                        long1 = Long.parseLong(split[1]);
                        if (long1 < 0L) {
                            long1 = (this.approved ? (Math.abs(long1) + this.approved_time) : -1L);
                        }
                    }
                    catch (Exception ex) {}
                }
            }
            return long1;
        }
        
        private final boolean commandAvailable(String s) {
            boolean n = false;
            if (VAuthEx.fixed_keys[this.run_mode].length > 0) {
                String[] array = VAuthEx.fixed_keys[this.run_mode];
                int length = array.length;
                int i = 0;
                while (i < length) {
                    if (array[i].equals(s)) {
                        n = true;
                        break;
                    }
                    else {
                        ++i;
                    }
                }
            }
            if (!n) {
                int j = 0;
                while (j < this.keyinfos.size()) {
                    String s2 = (String)this.keyinfos.get(j);
                    if (this.commandKey(s2).equals(s)) {
                        long commandTerm = this.commandTerm(s2);
                        if (commandTerm >= 0L) {
                            n = (commandTerm == 0L || System.currentTimeMillis() <= commandTerm);
                            break;
                        }
                        else {
                            break;
                        }
                    }
                    else {
                        ++j;
                    }
                }
            }
            return n;
        }
        
        private final String toStringExtra(boolean b) {
            StringBuilder sb = new StringBuilder();
            sb.append("DATETIME");
            sb.append('=');
            sb.append(System.currentTimeMillis());
            sb.append(';');
            sb.append("LICENCEID");
            sb.append('=');
            sb.append(this.licenceID);
            if (b) {
                sb.append(';');
                sb.append("TERMTYPE");
                sb.append('=');
                sb.append(this.term_type);
                sb.append(';');
                sb.append("TERM");
                sb.append('=');
                sb.append(this.term);
                sb.append(';');
                sb.append("TIMEADJUST");
                sb.append('=');
                sb.append(this.time_adjust);
                sb.append(';');
                sb.append("RUNMODE");
                sb.append('=');
                sb.append(this.run_mode);
                sb.append(';');
                sb.append("KEYS");
                sb.append('=');
                for (int i = 0, size = this.keyinfos.size(); i < size; ++i) {
                    sb.append(this.commandKey((String)this.keyinfos.get(i)));
                    if (i < size - 1) {
                        sb.append(',');
                    }
                }
                sb.append(';');
                sb.append("TITLE");
                sb.append('=');
                sb.append(this.title);
                sb.append(';');
                sb.append("COMMENT");
                sb.append('=');
                sb.append(this.comment);
                sb.append(';');
                sb.append("CID");
                sb.append('=');
                sb.append(this.cid);
                sb.append(';');
                sb.append("LIMITEDREGULAR");
                sb.append('=');
                sb.append(this.limited_regular);
                sb.append(';');
                sb.append("MEMORYSTANDARD");
                sb.append('=');
                sb.append(this.memory_standard);
            }
            return sb.toString();
        }
        
        private final boolean check(KEY key) {
            boolean n = false;
            if (key.getLicenceID().equals(this.licenceID)) {
                n = true;
            }
            else {
                String licenceID = key.getLicenceID();
                String licenceID2 = this.licenceID;
                if (licenceID.substring(0, licenceID.indexOf("-")).equals(licenceID2.substring(0, licenceID2.indexOf("-")))) {
                    String substring = licenceID.substring(licenceID.indexOf("-") + 1);
                    String substring2 = licenceID2.substring(licenceID2.indexOf("-") + 1);
                    try {
                        if (Math.abs(JSStringUtil.toValue62(substring) - JSStringUtil.toValue62(substring2)) < 2000L) {
                            n = true;
                        }
                    }
                    catch (Exception ex) {}
                }
            }
            return n;
        }
        
        private boolean checkTransferTerm() {
            return this.approved || (this.extend && System.currentTimeMillis() < this.approved_time);
        }
        
        private boolean checkMaxMemory() {
            boolean n = true;
            if (((this.isRunModeStandaloneLicence() && this.memory_standard) || (this.isRunModeServer() && VAuthEx.client32)) && JSSystem.getMaxMemory() > 8589934592L) {
                n = false;
            }
            if (this.isRunModeSuperEngineer()) {
                n = true;
            }
            return n;
        }
        
        private boolean checkPrefs() {
            boolean n = false;
            if (VAuthEx.sreg.exists(this.prefskey)) {
                n = true;
            }
            return n;
        }
        
        private boolean checkPrefskey(String s) {
            if (s == null || s.isEmpty()) {
                return false;
            }
            String[] split = s.split("-");
            return split != null && split.length == 6 && split[0].equals("B0285C");
        }
        
        private boolean checkHash(KEY key) {
            boolean collateFP = true;
            if (this.hashkey == 188900977659375L && this.hash != null && !this.hash.isEmpty() && this.hash.equals("SKIPSKIPSKIPSKIP")) {
                VAuthEx.log.println("!!! HASH SKIP !!!");
                return true;
            }
            if (this.approved) {
                JVWMI.setTargetDriveLetter(key.path.charAt(0));
                collateFP = JVWMI.collateFP(this.hashkey, this.hash);
            }
            return collateFP;
        }
        
        private void checkIndividuality() {
            if (this.extend && !this.prefskey.isEmpty() && this.individuality_level < this.individuality_max_level && this.individuality[this.individuality_level].isEmpty() && VAuthEx.sreg.start(this.prefskey)) {
                long currentTimeMillis = System.currentTimeMillis();
                long long1 = VAuthEx.sreg.getLong("UeNL1fag4", currentTimeMillis);
                long n = currentTimeMillis - long1;
                long long2 = VAuthEx.sreg.getLong("riwh5i54609n", 0L);
                long long3 = VAuthEx.sreg.getLong("lwihn381wai3", long1);
                if (n < REG.INDIVIDUALITY_LEVEL_TERM[this.individuality_level]) {
                    VAuthEx.sreg.putLong("riwh5i54609n", long2 + currentTimeMillis);
                }
                else {
                    SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyyMMddHHmmss");
                    long currentTimeMillis2 = System.currentTimeMillis();
                    this.individuality[this.individuality_level] = String.format("%s-%s-%d", new Object[] { simpleDateFormat.format(new Date(long3)), simpleDateFormat.format(new Date(currentTimeMillis2)), Long.valueOf(long2) });
                    VAuthEx.sreg.putLong("riwh5i54609n", 0L);
                    VAuthEx.sreg.putLong("lwihn381wai3", currentTimeMillis2);
                    ++this.individuality_level;
                    this.save();
                }
                VAuthEx.sreg.end();
            }
        }
        
        private final String getCompanyID() {
            return this.cid;
        }
        
        private final boolean isRunModeUnApproved() {
            return this.run_mode == 5;
        }
        
        private final boolean isRunModeViewer() {
            return this.run_mode == 2;
        }
        
        private final boolean isRunModeServer() {
            return this.run_mode == 3;
        }
        
        private final boolean isRunModeTrial() {
            return this.run_mode == 0;
        }
        
        private final boolean isRunModeRegular() {
            return this.run_mode == 1 && !this.limited_regular;
        }
        
        private final boolean isRunModeLimitedRegular() {
            return this.run_mode == 1 && this.limited_regular;
        }
        
        private final boolean isRunModeStandaloneLicence() {
            return this.isRunModeTrial() || this.isRunModeRegular() || this.isRunModeLimitedRegular();
        }
        
        private final boolean isRunModeSuperEngineer() {
            return this.run_mode == -1;
        }
        
        private final long getLimitedRegularTerm() {
            return this.term;
        }
        
        private final boolean isMemoryStandard() {
            return this.memory_standard;
        }
        
        private final boolean isAvailableCommand(String s) {
            boolean n = false;
            if (this.isRunModeViewer()) {
                n = this.commandAvailable(s);
            }
            else if (this.isRunModeServer()) {
                n = (Bridge.isLevelSuperUser(this.level) || this.commandAvailable(s));
            }
            else if (this.isRunModeStandaloneLicence()) {
                n = this.commandAvailable(s);
            }
            else if (this.isRunModeSuperEngineer()) {
                n = true;
            }
            else if (VAuthEx.remote_worker) {
                n = true;
            }
            return n;
        }
        
        private final void setServerInfo(byte level, String s) {
            this.level = level;
            this.keyinfos.clear();
            if (s != null && !s.isEmpty()) {
                String[] split = s.split(",");
                for (int length = split.length, i = 0; i < length; ++i) {
                    this.keyinfos.add(split[i]);
                }
            }
        }
    }
    
    private static class HST
    {
        private File fhst;
        private long start;
        private long base;
        private long running;
        private long laststart;
        private long lastend;
        private boolean started;
        private boolean ended;
        
        private HST(File fhst) throws SecurityException {
            this.started = false;
            this.ended = false;
            this.fhst = fhst;
            this.start = System.currentTimeMillis();
            this.base = this.start;
        }
        
        private void load() {
            if (!this.fhst.exists()) {
                return;
            }
            try {
                RandomAccessFile randomAccessFile = new RandomAccessFile(this.fhst, "rw");
                try {
                    FileChannel channel = randomAccessFile.getChannel();
                    FileLock tryLock = null;
                    while (tryLock == null) {
                        tryLock = channel.tryLock();
                        if (tryLock != null) {
                            break;
                        }
                        else {
                            ThreadEx.sleeping(500L);
                        }
                    }
                    try {
                        byte[] b = new byte[4096];
                        ByteUtil.cryptXor(b, 0, randomAccessFile.read(b), 138);
                        int[] array = { 0 };
                        ByteUtil.readDouble(b, array);
                        this.running = ByteUtil.readLong(b, array);
                        ByteUtil.readDouble(b, array);
                        this.laststart = ByteUtil.readLong(b, array);
                        this.lastend = ByteUtil.readLong(b, array);
                        ByteUtil.readDouble(b, array);
                    }
                    finally {
                        tryLock.release();
                    }
                }
                finally {
                    randomAccessFile.close();
                }
            }
            catch (IOException ex) {
                throw new SecurityException("*exception* hst " + ex.getMessage() + "[H3]");
            }
            catch (Exception ex2) {}
            catch (Error error) {}
        }
        
        private void save() {
            boolean n = false;
            try {
                FileOutputStream fileOutputStream = new FileOutputStream(this.fhst);
                try {
                    FileChannel channel = fileOutputStream.getChannel();
                    FileLock tryLock = null;
                    while (tryLock == null) {
                        tryLock = channel.tryLock();
                        if (tryLock != null) {
                            break;
                        }
                        else {
                            ThreadEx.sleeping(500L);
                        }
                    }
                    try {
                        Random o = new Random();
                        DataOutputStream o2 = new DataOutputStream(new JSCryptOutputStream(fileOutputStream, 138));
                        o2.writeDouble(o.nextDouble());
                        o2.writeLong(this.running);
                        o2.writeDouble(o.nextDouble());
                        o2.writeLong(this.laststart);
                        o2.writeLong(this.lastend);
                        o2.writeDouble(o.nextDouble());
                        n = true;
                    }
                    finally {
                        tryLock.release();
                        channel.close();
                    }
                }
                finally {
                    fileOutputStream.close();
                }
            }
            catch (IOException ex) {
                throw new SecurityException("*exception* hst " + ex.getMessage() + "[H4]");
            }
            catch (Exception ex2) {}
            catch (Error error) {}
            if (n) {
                ThreadEx.sleeping(100L);
                this.fhst.setLastModified(VAuthEx.stamptime_hst);
            }
        }
        
        private void start() {
            if (this.started) {
                return;
            }
            this.started = true;
            this.load();
            this.laststart = System.currentTimeMillis();
            this.save();
        }
        
        private void update() {
            this.load();
            long currentTimeMillis = System.currentTimeMillis();
            this.running += Math.abs(currentTimeMillis - this.base);
            this.base = currentTimeMillis;
            this.save();
        }
        
        private void end() {
            if (this.ended) {
                return;
            }
            this.ended = true;
            this.load();
            long currentTimeMillis = System.currentTimeMillis();
            this.running += Math.abs(currentTimeMillis - this.base);
            this.lastend = currentTimeMillis;
            this.save();
        }
        
        private void check(REG reg) {
            try {
                long access$800 = reg.time_adjust;
                if (this.fhst.exists() && this.fhst.length() == 0L) {
                    throw new SecurityException(Message.get(221) + "[H1]");
                }
                this.load();
                long currentTimeMillis = System.currentTimeMillis();
                long max = Math.max(this.laststart, this.lastend);
                if (currentTimeMillis < max && Math.abs(max - currentTimeMillis) > access$800) {
                    throw new SecurityException(Message.get(222) + "[H2]");
                }
            }
            catch (Exception ex) {
                if (!reg.isRunModeRegular() && !reg.isRunModeServer()) {
                    throw ex;
                }
            }
        }
        
        private boolean checkLimit(int n, long n2) {
            boolean n3 = true;
            switch (n) {
                case 0: {
                    n3 = (this.running >= 0L && this.running <= n2);
                    break;
                }
                case 1: {
                    n3 = (System.currentTimeMillis() <= n2);
                    break;
                }
            }
            return n3;
        }
    }
    
    private static class VAF
    {
        private String company;
        private String licenceID;
        private String uniqueID;
        private long hashkey;
        private String hash;
        private int runMode;
        private boolean trialTermInc;
        private long trialTerm;
        private boolean limitedRegular;
        private boolean regularTermInc;
        private long regularTerm;
        private long timeAdjust;
        private long maintenance_term;
        private String cid;
        private boolean memoryStandard;
        private int menuversion;
        private String menuname;
        private String menukeys;
        private String title;
        private String comment;
        private boolean b1;
        private boolean b2;
        private int i1;
        private int i2;
        private long l1;
        private long l2;
        
        private VAF(String s, File file) throws SecurityException {
            boolean n = false;
            try {
                BufferedInputStream bufferedInputStream = new BufferedInputStream(new FileInputStream(file));
                try {
                    int n2 = (int)((double)file.length() * 1.2);
                    int n3 = 0;
                    byte[] array = new byte[n2];
                    byte[] b = new byte[1024];
                    while (true) {
                        int read = bufferedInputStream.read(b);
                        if (read == -1) {
                            break;
                        }
                        else {
                            System.arraycopy(b, 0, array, n3, read);
                            n3 += read;
                        }
                    }
                    byte[] base64Data = new byte[n3];
                    System.arraycopy(array, 0, base64Data, 0, n3);
                    SecretKeySpec key = new SecretKeySpec("8Zi50pW_qS4$OX1!".getBytes("UTF-8"), "AES");
                    Cipher instance = Cipher.getInstance("AES");
                    instance.init(2, key);
                    ByteBufferStream o = new ByteBufferStream(ByteBuffer.wrap(instance.doFinal(Base64.decodeBase64(base64Data))));
                    o.getInt();
                    int int1 = o.getInt();
                    int i = 0;
                    while (i < int1) {
                        String string = o.getString();
                        String string2 = s;
                        String string3 = o.getString();
                        long long1 = o.getLong();
                        String string4 = o.getString();
                        int int2 = o.getInt();
                        boolean boolean1 = o.getBoolean();
                        long long2 = o.getLong();
                        boolean boolean2 = o.getBoolean();
                        boolean boolean3 = o.getBoolean();
                        long long3 = o.getLong();
                        long long4 = o.getLong();
                        long long5 = o.getLong();
                        String string5 = o.getString();
                        boolean boolean4 = o.getBoolean();
                        int int3 = o.getInt();
                        String string6 = o.getString();
                        String string7 = o.getString();
                        String string8 = o.getString();
                        String string9 = o.getString();
                        boolean boolean5 = o.getBoolean();
                        boolean boolean6 = o.getBoolean();
                        int int4 = o.getInt();
                        int int5 = o.getInt();
                        long long6 = o.getLong();
                        long long7 = o.getLong();
                        JOptionPane.showMessageDialog(null, "1111:" + string2 + ":" + s);
                        if (string2.equals(s)) {
                            n = true;
                            this.company = string;
                            this.licenceID = string2;
                            this.uniqueID = string3;
                            this.hashkey = long1;
                            this.hash = string4;
                            this.runMode = int2;
                            this.trialTermInc = boolean1;
                            this.trialTerm = long2;
                            this.limitedRegular = boolean2;
                            this.regularTermInc = boolean3;
                            this.regularTerm = long3;
                            this.timeAdjust = long4;
                            this.maintenance_term = long5;
                            this.cid = string5;
                            this.memoryStandard = boolean4;
                            this.menuversion = int3;
                            this.menuname = string6;
                            this.menukeys = string7;
                            this.title = string8;
                            this.comment = string9;
                            this.b1 = boolean5;
                            this.b2 = boolean6;
                            this.i1 = int4;
                            this.i2 = int5;
                            this.l1 = long6;
                            this.l2 = long7;
                            break;
                        }
                        else {
                            ++i;
                        }
                    }
                }
                finally {
                    bufferedInputStream.close();
                }
            }
            catch (Exception ex) {
                JOptionPane.showMessageDialog(null, ex.getStackTrace()[0].toString());
                throw new SecurityException("*exception* VAF loading failed. " + ex.getMessage());
            }
            finally {
                if (!n) {
                    throw new SecurityException("*error* VAF loading failed. " + s + " is not exist in " + file.getAbsolutePath() + ". [VAF0]");
                }
            }
        }
    }
    
    private static class UnApprovedDialog extends JSDialog implements ActionListener
    {
        private REG reg;
        private File fpv;
        private boolean exist;
        private JLabel lblMessage;
        private JButton btnFolder;
        private JLabel lblVAF;
        private JButton btnApplyVAF;
        private Desktop d;
        private char[] sep;
        private int sepc;
        private KeyAdapter seKeyListener;
        
        UnApprovedDialog(REG reg, File fpv, boolean exist) {
            super(Resource.get("Authentication"), true);
            this.d = Desktop.getDesktop();
            this.sep = new char[] { 'F', 'U', '7', '4', 'b', 'u', '4', '8', '!' };
            this.sepc = 0;
            this.seKeyListener = new KeyAdapter() {
                @Override
                public void keyTyped(KeyEvent keyEvent) {
                    int modifiers = keyEvent.getModifiers();
                    int keyChar = keyEvent.getKeyChar();
                    if (JSGuiTools.isAlt(modifiers)) {
                        if (keyChar == UnApprovedDialog.this.sep[UnApprovedDialog.this.sepc]) {
                            UnApprovedDialog this$1 = UnApprovedDialog.this;
                            ++VAuthEx$UnApprovedDialog.this.sepc;
                            if (UnApprovedDialog.this.sepc == 9) {
                                UnApprovedDialog.this.reg.run_mode = -1;
                                reg.save();
                                JSMessageDialog.informationOK(null, null, 69, new Object[0]);
                                System.exit(0);
                            }
                        }
                        else {
                            UnApprovedDialog.this.sepc = 0;
                        }
                    }
                    else {
                        UnApprovedDialog.this.sepc = 0;
                    }
                }
            };
            this.reg = reg;
            this.fpv = fpv;
            this.exist = exist;
            JPanel leftAccessory = new JPanel(new BorderLayout());
            JLabel comp = new JLabel(new ImageIcon(ClassLoader.getSystemResource("stella/resource/image/StellaLogo145x236.gif")));
            comp.setBorder(new EtchedBorder(1));
            leftAccessory.add(comp, "North");
            this.setLeftAccessory(leftAccessory);
            this.lblMessage = (exist ? new JLabel(Message.get(216, new Object[] { fpv.getAbsolutePath(), "AUTHORIZATION.VAF", DT.strDate(reg.approved_time), "LICENCE.FPV " + Resource.get("Folder"), "AUTHORIZATION.VAF" })) : new JLabel(Message.get(215, new Object[] { fpv.getAbsolutePath(), "AUTHORIZATION.VAF", "LICENCE.FPV " + Resource.get("Folder"), "AUTHORIZATION.VAF" })));
            (this.btnFolder = new JButton("LICENCE.FPV " + Resource.get("Folder"))).addActionListener(this);
            this.lblVAF = new JLabel("AUTHORIZATION.VAF" + Resource.get(":"));
            (this.btnApplyVAF = new JButton(Resource.get("Apply"))).addActionListener(this);
            if (VAuthEx.allusers && VAuthEx.os_windows) {
                this.btnApplyVAF.setEnabled(JSSystem.isWindowsActualAdministratorUser());
            }
            DM.start(this.panelUser);
            DM.add(this.lblMessage);
            DM.addReturn();
            if (this.d.isSupported(Desktop.Action.OPEN)) {
                DM.add(this.btnFolder);
            }
            DM.addIndent(40);
            DM.add(this.lblVAF, DM.defVCenter);
            DM.add(this.btnApplyVAF, DM.defVCenter);
            DM.end();
            this.panelUser.setBorder(new EmptyBorder(10, 10, 10, 10));
            this.setSystemButtons(new int[] { exist ? (reg.checkTransferTerm() ? 13 : 18) : 18 });
            leftAccessory.setBorder(new EmptyBorder((this.getContentPane().getPreferredSize().height - comp.getPreferredSize().height) / 2, 20, 10, 10));
            this.btnFolder.addKeyListener(this.seKeyListener);
            this.btnApplyVAF.addKeyListener(this.seKeyListener);
        }
        
        public final void actionPerformed(ActionEvent actionEvent) {
            Object source = actionEvent.getSource();
            if (source == this.btnFolder) {
                this.doFolder();
            }
            else if (source == this.btnApplyVAF) {
                this.doApplyVAF();
            }
        }
        
        private void doFolder() {
            try {
                this.d.open(this.fpv.getParentFile());
            }
            catch (IOException ex) {}
        }
        
        private void doApplyVAF() {
            FileFilter fileFilter = new FileFilter() {
                @Override
                public boolean accept(File file) {
                    if (file.isDirectory()) {
                        return true;
                    }
                    String name = file.getName();
                    int lastIndex = name.lastIndexOf(46);
                    return lastIndex > 0 && name.substring(lastIndex).equalsIgnoreCase(".VAF");
                }
                
                @Override
                public String getDescription() {
                    return "AUTHORIZATION.VAF";
                }
            };
            JFileChooser fileChooser = new JFileChooser();
            fileChooser.setDialogTitle("AUTHORIZATION.VAF");
            fileChooser.setDialogType(0);
            fileChooser.setFileSelectionMode(0);
            fileChooser.setMultiSelectionEnabled(false);
            fileChooser.setFileFilter(fileFilter);
            fileChooser.setCurrentDirectory(this.fpv.getParentFile());
            if (fileChooser.showOpenDialog(this.btnApplyVAF) == 0) {
                File selectedFile = fileChooser.getSelectedFile();
                try {
                    this.reg.apply(new VAF(this.reg.licenceID, selectedFile), false);
                    updateBin(true);
                    JSMessageDialog.informationOK(this, null, 54, new Object[0]);
                    this.dismiss(18);
                    if (this.exist) {
                        System.exit(0);
                    }
                }
                catch (SecurityException ex) {
                    JSMessageDialog.errorOK(this, null, 217, new Object[] { ex.getMessage() });
                }
            }
        }
    }
    
    private static class LicenceUpdateDialog extends JSDialog implements ActionListener
    {
        private REG reg;
        private File fpv;
        private JLabel lblMessage;
        private JButton btnFolder;
        private JLabel lblVAF;
        private JButton btnApplyVAF;
        private Desktop d;
        
        LicenceUpdateDialog(REG reg, File fpv, boolean b) {
            super(Resource.get("Authentication"), true);
            this.d = Desktop.getDesktop();
            this.reg = reg;
            this.fpv = fpv;
            JPanel leftAccessory = new JPanel(new BorderLayout());
            JLabel comp = new JLabel(new ImageIcon(ClassLoader.getSystemResource("stella/resource/image/StellaLogo145x236.gif")));
            comp.setBorder(new EtchedBorder(1));
            leftAccessory.add(comp, "North");
            this.setLeftAccessory(leftAccessory);
            this.lblMessage = new JLabel(Message.get(264, new Object[] { "AUTHORIZATION.VAF" }));
            (this.btnFolder = new JButton("LICENCE.FPV " + Resource.get("Folder"))).addActionListener(this);
            this.lblVAF = new JLabel("AUTHORIZATION.VAF" + Resource.get(":"));
            (this.btnApplyVAF = new JButton(Resource.get("Apply"))).addActionListener(this);
            if (VAuthEx.allusers && VAuthEx.os_windows) {
                this.btnApplyVAF.setEnabled(JSSystem.isWindowsActualAdministratorUser());
            }
            DM.start(this.panelUser);
            DM.add(this.lblMessage);
            DM.addReturn();
            if (this.d.isSupported(Desktop.Action.OPEN)) {
                DM.add(this.btnFolder);
            }
            DM.addIndent(40);
            DM.add(this.lblVAF, DM.defVCenter);
            DM.add(this.btnApplyVAF, DM.defVCenter);
            DM.end();
            this.panelUser.setBorder(new EmptyBorder(10, 10, 10, 10));
            this.setSystemButtons(new int[] { b ? (reg.checkTransferTerm() ? 13 : 18) : 18 });
            leftAccessory.setBorder(new EmptyBorder((this.getContentPane().getPreferredSize().height - comp.getPreferredSize().height) / 2, 20, 10, 10));
        }
        
        public final void actionPerformed(ActionEvent actionEvent) {
            Object source = actionEvent.getSource();
            if (source == this.btnFolder) {
                this.doFolder();
            }
            else if (source == this.btnApplyVAF) {
                this.doApplyVAF();
            }
        }
        
        private void doFolder() {
            try {
                this.d.open(this.fpv.getParentFile());
            }
            catch (IOException ex) {}
        }
        
        private void doApplyVAF() {
            FileFilter fileFilter = new FileFilter() {
                @Override
                public boolean accept(File file) {
                    if (file.isDirectory()) {
                        return true;
                    }
                    String name = file.getName();
                    int lastIndex = name.lastIndexOf(46);
                    return lastIndex > 0 && name.substring(lastIndex).equalsIgnoreCase(".VAF");
                }
                
                @Override
                public String getDescription() {
                    return "AUTHORIZATION.VAF";
                }
            };
            JFileChooser fileChooser = new JFileChooser();
            fileChooser.setDialogTitle("AUTHORIZATION.VAF");
            fileChooser.setDialogType(0);
            fileChooser.setFileSelectionMode(0);
            fileChooser.setMultiSelectionEnabled(false);
            fileChooser.setFileFilter(fileFilter);
            fileChooser.setCurrentDirectory(this.fpv.getParentFile());
            if (fileChooser.showOpenDialog(this.btnApplyVAF) == 0) {
                File selectedFile = fileChooser.getSelectedFile();
                try {
                    VAF vaf = new VAF(this.reg.licenceID, selectedFile);
                    boolean b = this.reg.memory_standard ^ vaf.memoryStandard;
                    if (Boolean.getBoolean("debug.vaf.mx")) {
                        System.out.println(String.format("reset_mx:%s (reg:%s vaf:%s)", new Object[] { Boolean.valueOf(b), Boolean.valueOf(this.reg.memory_standard), Boolean.valueOf(vaf.memoryStandard) }));
                    }
                    this.reg.apply(vaf, false);
                    updateBin(b);
                    JSMessageDialog.informationOK(this, null, 54, new Object[0]);
                    this.dismiss(18);
                    System.exit(0);
                }
                catch (SecurityException ex) {
                    JSMessageDialog.errorOK(this, null, 217, new Object[] { ex.getMessage() });
                }
            }
        }
    }
    
    private static class LicenceUpdateMenuItem extends JMenuItem implements ActionListener
    {
        private LicenceUpdateMenuItem() {
            super(Resource.getCont("LicenceUpdate"));
            this.setIcon(new ImageIcon(this.getClass().getResource("UpdateLicence.gif")));
            this.addActionListener(this);
        }
        
        private void doApplyVAF() {
            Window windowAncestor = SwingUtilities.getWindowAncestor(this);
            if (JSMessageDialog.warningOKCancel(windowAncestor, null, 255, new Object[0]) == 1) {
                return;
            }
            File access$11100 = createFPV(true);
            if (access$11100 != null) {
                if (VAuthEx.allusers && VAuthEx.os_windows && !JSSystem.isWindowsActualAdministratorUser()) {
                    JSMessageDialog.warningOK(windowAncestor, null, 263, new Object[0]);
                }
                LicenceUpdateDialog licenceUpdateDialog = new LicenceUpdateDialog(VAuthEx.reg, access$11100, false);
                try {
                    licenceUpdateDialog.start();
                }
                finally {
                    licenceUpdateDialog.end();
                }
            }
        }
        
        @Override
        public final void actionPerformed(ActionEvent actionEvent) {
            this.doApplyVAF();
        }
    }
    
    private static class MNU
    {
        private int version;
        private int menuversion;
        private String menuname;
        private String menukeys;
        
        private MNU(File file) throws SecurityException {
            try {
                BufferedInputStream bufferedInputStream = new BufferedInputStream(new FileInputStream(file));
                try {
                    int len = (int)file.length();
                    byte[] array = new byte[len];
                    if (bufferedInputStream.read(array, 0, len) == len) {
                        SecretKeySpec key = new SecretKeySpec("2V$wI81&!!uQ0@ee".getBytes("UTF-8"), "AES");
                        Cipher instance = Cipher.getInstance("AES");
                        instance.init(2, key);
                        byte[] doFinal = instance.doFinal(Base64.decodeBase64(array));
                        int[] array2 = { 0 };
                        int int1 = ByteUtil.readInt(doFinal, array2);
                        int int2 = ByteUtil.readInt(doFinal, array2);
                        String utf = ByteUtil.readUTF(doFinal, array2);
                        String utf2 = ByteUtil.readUTF(doFinal, array2);
                        this.version = int1;
                        this.menuversion = int2;
                        this.menuname = utf;
                        this.menukeys = utf2;
                    }
                    else {
                        throw new SecurityException("Bad size.");
                    }
                }
                finally {
                    bufferedInputStream.close();
                }
            }
            catch (Exception ex) {
                throw new SecurityException(ex.getMessage());
            }
        }
    }
    
    private static class ViewerLicenceUpdateMenuItem extends JMenuItem implements ActionListener
    {
        private ViewerLicenceUpdateMenuItem() {
            super(Resource.getCont("ViewerLicenceUpdate"));
            this.setIcon(new ImageIcon(this.getClass().getResource("UpdateLicence.gif")));
            this.addActionListener(this);
        }
        
        private void doUpdate() {
            Window windowAncestor = SwingUtilities.getWindowAncestor(this);
            if (JSMessageDialog.warningOKCancel(windowAncestor, null, 261, new Object[0]) == 1) {
                return;
            }
            FileFilter fileFilter = new FileFilter() {
                @Override
                public boolean accept(File file) {
                    return file.isDirectory() || file.getName().toUpperCase().equals("VIEWER.MNU");
                }
                
                @Override
                public String getDescription() {
                    return "VIEWER.MNU";
                }
            };
            JFileChooser fileChooser = new JFileChooser();
            fileChooser.setDialogTitle("VIEWER.MNU");
            fileChooser.setDialogType(0);
            fileChooser.setFileSelectionMode(0);
            fileChooser.setMultiSelectionEnabled(false);
            fileChooser.setFileFilter(fileFilter);
            if (fileChooser.showOpenDialog(windowAncestor) == 0) {
                File selectedFile = fileChooser.getSelectedFile();
                try {
                    VAuthEx.reg.apply(new MNU(selectedFile));
                    JSMessageDialog.informationOK(windowAncestor, null, 54, new Object[0]);
                    System.exit(0);
                }
                catch (SecurityException ex) {
                    JSMessageDialog.errorOK(windowAncestor, null, 262, new Object[0]);
                }
            }
        }
        
        @Override
        public final void actionPerformed(ActionEvent actionEvent) {
            this.doUpdate();
        }
    }
}
